package com.zcloud.controller.app.inspection;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.service.inspection.SafetyEnvironmentalInspectorService;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：安全环保检查人员
 * 作者：luoxiaobao
 * 时间：2022-06-08
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/safetyenvironmentalinspector")
public class AppSafetyEnvironmentalInspectorController extends BaseController {

    @Autowired
    private SafetyEnvironmentalInspectorService safetyenvironmentalinspectorService;

    @Autowired
    private Smb smb;

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/list")
    @ResponseBody
    public Object list(Page page) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String KEYWORDS = pd.getString("KEYWORDS");                        //关键词检索条件
        if (Tools.notEmpty(KEYWORDS)) pd.put("KEYWORDS", KEYWORDS.trim());
        page.setPd(pd);
        List<PageData> varList = safetyenvironmentalinspectorService.list(page);    //列出SafetyEnvironmentalInspector列表
        map.put("varList", varList);
        map.put("page", page);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 检查人核实
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/verify")
    @ResponseBody
    public Object verify(@RequestParam(value = "FFILE", required = false) MultipartFile[] files) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        PageData uBean = safetyenvironmentalinspectorService.findById(pd);
        uBean.put("INSPECTION_USER_OPINION", pd.getString("INSPECTION_USER_OPINION"));
        uBean.put("INSPECTED_SITEUSER_SIGN_IMG", pd.getString("INSPECTED_SITEUSER_SIGN_IMG"));
        uBean.put("INSPECTION_USER_SIGN_TIME", pd.getString("INSPECTION_USER_SIGN_TIME"));
        uBean.put("INSPECTION_STATUS", pd.getString("INSPECTION_STATUS"));    //检查进度状态
        uBean.put("OPERATOR", pd.getString("OPERATOR"));    //修改人
        uBean.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        uBean.put("ACTION_USER", pd.getString("ACTION_USER"));    //操作人
        if (files != null && files.length > 0) {
            MultipartFile file = files[0];
            String suffixName = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf(".")+1).toLowerCase();
            if (!"pdf".equals(suffixName) && !"jpg".equals(suffixName) && !"jpeg".equals(suffixName) && !"png".equals(suffixName) && !"mp4".equals(suffixName)) {
                errInfo = "fail";
                map.put("result", errInfo);
                map.put("msg", "文件格式不正确！");
                return map;
            }

            String ffile = DateUtil.getDays();
            String fileName = this.get32UUID() + file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
            smb.sshSftp(file, fileName, Const.FILEPATHFILE + pd.getString("CORPINFO_ID") + "/" + ffile);

            uBean.put("INSPECTION_USER_SIGN_IMG", Const.FILEPATHFILE + pd.getString("CORPINFO_ID") + "/" + ffile + "/" + fileName);
        }
        safetyenvironmentalinspectorService.verify(uBean);
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 新增
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/add")
    // @RequiresPermissions("safetyenvironmentalinspector:add")
    @ResponseBody
    public Object add() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("INSPECTION_INSPECTOR_ID", this.get32UUID());    //主键
        pd.put("ISDELETE", "");    //是否删除(0:有效 1：删除)
        pd.put("CREATOR", Jurisdiction.getUSER_ID());    //添加人
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATOR", Jurisdiction.getUSER_ID());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        safetyenvironmentalinspectorService.save(pd);
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/delete")
    // @RequiresPermissions("safetyenvironmentalinspector:del")
    @ResponseBody
    public Object delete() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUSER_ID());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        safetyenvironmentalinspectorService.delete(pd);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/edit")
    // @RequiresPermissions("safetyenvironmentalinspector:edit")
    @ResponseBody
    public Object edit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUSER_ID());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        safetyenvironmentalinspectorService.edit(pd);
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去修改页面获取数据
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goEdit")
    // @RequiresPermissions("safetyenvironmentalinspector:edit")
    @ResponseBody
    public Object goEdit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd = safetyenvironmentalinspectorService.findById(pd);    //根据ID读取
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 批量删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/deleteAll")
    // @RequiresPermissions("safetyenvironmentalinspector:del")
    @ResponseBody
    public Object deleteAll() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUSER_ID());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        String DATA_IDS = pd.getString("DATA_IDS");
        if (Tools.notEmpty(DATA_IDS)) {
            String[] ArrayDATA_IDS = DATA_IDS.split(",");
            pd.put("ArrayDATA_IDS", ArrayDATA_IDS);    //待删除ids
            safetyenvironmentalinspectorService.deleteAll(pd);
            errInfo = "success";
        } else {
            errInfo = "fail";
        }
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 导出到excel
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/excel")
    // @RequiresPermissions("toExcel")
    public ModelAndView exportExcel() throws Exception {
        ModelAndView mv = new ModelAndView();
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> dataMap = new HashMap<String, Object>();
        List<String> titles = new ArrayList<String>();
        titles.add("安全环保检查ID");    //1
        titles.add("检查人");    //2
        titles.add("检查人意见（有异议时必填）");    //3
        titles.add("检查人签字");    //4
        titles.add("检查人签字时间");    //5
        titles.add("是否删除(0:有效 1：删除)");    //6
        titles.add("添加人");    //7
        titles.add("添加时间");    //8
        titles.add("修改人");    //9
        titles.add("修改时间");    //10
        titles.add("企业ID");    //11
        dataMap.put("titles", titles);
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        List<PageData> varOList = safetyenvironmentalinspectorService.listAll(pd);
        List<PageData> varList = new ArrayList<PageData>();
        for (int i = 0; i < varOList.size(); i++) {
            PageData vpd = new PageData();
            vpd.put("var1", varOList.get(i).getString("INSPECTION_ID"));        //1
            vpd.put("var2", varOList.get(i).getString("INSPECTION_USER_ID"));        //2
            vpd.put("var3", varOList.get(i).getString("INSPECTION_USER_OPINION"));        //3
            vpd.put("var4", varOList.get(i).getString("INSPECTION_USER_SIGN_IMG"));        //4
            vpd.put("var5", varOList.get(i).getString("INSPECTION_USER_SIGN_TIME"));        //5
            vpd.put("var6", varOList.get(i).getString("ISDELETE"));        //6
            vpd.put("var7", varOList.get(i).getString("CREATOR"));        //7
            vpd.put("var8", varOList.get(i).getString("CREATTIME"));        //8
            vpd.put("var9", varOList.get(i).getString("OPERATOR"));        //9
            vpd.put("var10", varOList.get(i).getString("OPERATTIME"));        //10
            vpd.put("var11", varOList.get(i).getString("CORPINFO_ID"));        //11
            varList.add(vpd);
        }
        dataMap.put("varList", varList);
        ObjectExcelView erv = new ObjectExcelView();
        mv = new ModelAndView(erv, dataMap);
        return mv;
    }

}
