package com.zcloud.controller.archives;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.archives.ArchivesTeacherService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：本单位师资管理台账
 * 作者：luoxiaobao
 * 时间：2021-12-16
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/archivesteacher")
public class ArchivesTeacherController extends BaseController {

	@Autowired
	private ArchivesTeacherService archivesteacherService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一企一档",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("ARCHIVESTEACHER_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE",0);	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		archivesteacherService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一企一档",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		archivesteacherService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一企一档",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		archivesteacherService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一企一档",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业
		List<PageData> varList = archivesteacherService.listAll(pd);	//列出ArchivesTeacher列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一企一档",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = archivesteacherService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			archivesteacherService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("姓名");	//1
		titles.add("电话");	//2
		titles.add("从事本专业工作年限");	//3
		titles.add("专/兼职");	//4
		titles.add("证书编号");	//5
		titles.add("考核部门");	//6
		titles.add("考核日期");	//7
		titles.add("考核结果");	//8
		titles.add("备注");	//9
		titles.add("企业");	//10
		titles.add("年");	//11
		titles.add("是否删除");	//12
		titles.add("添加人");	//13
		titles.add("添加时间");	//14
		titles.add("修改人");	//15
		titles.add("修改时间");	//16
		dataMap.put("titles", titles);
		List<PageData> varOList = archivesteacherService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("PHONE"));	    //2
			vpd.put("var3", varOList.get(i).get("WORK_YEAR").toString());	//3
			vpd.put("var4", varOList.get(i).getString("OCCUPATION"));	    //4
			vpd.put("var5", varOList.get(i).getString("CARD_ID"));	    //5
			vpd.put("var6", varOList.get(i).getString("ASSESSMENT_DEPT"));	    //6
			vpd.put("var7", varOList.get(i).getString("ASSESSMENT_DATE"));	    //7
			vpd.put("var8", varOList.get(i).getString("ASSESSMENT_RESULT"));	    //8
			vpd.put("var9", varOList.get(i).getString("DESCR"));	    //9
			vpd.put("var10", varOList.get(i).getString("CORPINFO_ID"));	    //10
			vpd.put("var11", varOList.get(i).getString("YEAR"));	    //11
			vpd.put("var12", varOList.get(i).get("ISDELETE").toString());	//12
			vpd.put("var13", varOList.get(i).getString("CREATOR"));	    //13
			vpd.put("var14", varOList.get(i).getString("CREATTIME"));	    //14
			vpd.put("var15", varOList.get(i).getString("OPERATOR"));	    //15
			vpd.put("var16", varOList.get(i).getString("OPERATTIME"));	    //16
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
