package com.zcloud.controller.commitment;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.commitment.CommitmentCompanyService;
import com.zcloud.service.system.DepartmentService;
import com.zcloud.util.Const;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Smb;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 说明：公司级承诺
 * 作者：luoxiaobao
 * 时间：2021-10-08
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/commitmentcompany")
public class AppCommitmentCompanyController extends BaseController {

	@Autowired
	private CommitmentCompanyService commitmentcompanyService;
	@Autowired
	private DepartmentService departmentService;
	@Autowired
	private Smb smb;
	/**新增前检查
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/check")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "新增前检查")
	public Object check() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		PageData dept = departmentService.findById(pd);
//		if(!dept.get("LEVEL").equals("departmentLevel0001")){
		if(!dept.get("PARENT_ID").equals("0")){
			errInfo = "fail";
			map.put("msg", "无此权限");
		}
		pd.put("SIGN_TIME", DateUtil.date2Str(new Date()));   // 创建时间
		if(commitmentcompanyService.listAll(pd).size()>0){
			errInfo = "fail";
			map.put("msg", "本日公司安全承诺已完成，无法重复承诺");
		}
		map.put("result", errInfo);
		return map;
	}

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "新增")
	public Object add(@RequestParam(value="FFILE",required=false) MultipartFile[] files) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("COMMITMENTCOMPANY_ID", this.get32UUID());	//主键
		if (files != null && files.length > 0) {
			MultipartFile file = files[0];
			String  ffile = DateUtil.getDays();
			String fileName = this.get32UUID()+file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
			smb.sshSftp(file, fileName, Const.FILEPATHFILE + pd.getString("CORPINFO_ID") + "/"  + ffile);

			pd.put("SIGN_PATH",  Const.FILEPATHFILE + pd.getString("CORPINFO_ID") + "/" + ffile + "/" + fileName);
			pd.put("SIGN_TIME",  DateUtil.date2Str(new Date()));
		}
		commitmentcompanyService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("commitmentcompany:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		commitmentcompanyService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("commitmentcompany:edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		commitmentcompanyService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		page.setPd(pd);
		List<PageData>	varList = commitmentcompanyService.list(page);	//列出CommitmentCompany列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = commitmentcompanyService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("commitmentcompany:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "公司级承诺",instructionsOperate = "公司级承诺",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			commitmentcompanyService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}


}
