package com.zcloud.controller.corp;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.corp.QualificationsService;
import com.zcloud.service.system.ImgFilesService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：行业资质
 * 作者：luoxiaobao
 * 时间：2021-01-07
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/qualifications")
public class QualificationsController extends BaseController {

	@Autowired
	private QualificationsService qualificationsService;
	@Autowired
	private ImgFilesService imgFilesService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("qualifications:add")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("QUALIFICATIONS_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
		pd.put("ISDELETE", "0");	//是否删除 1-是  0-否
		qualificationsService.save(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("qualifications:del")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		qualificationsService.delete(pd);
		PageData pd2 = new PageData();
		pd2.put("FOREIGN_KEY", pd.getString("QUALIFICATIONS_ID"));
		pd2.put("TYPE",6);
		List<PageData> imgs = imgFilesService.listAll(pd2);//隐患图片
		if(imgs != null && imgs.size() > 0) {
			for (PageData pageData : imgs) {
				imgFilesService.delete(pageData);
			}
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("qualifications:edit")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		qualificationsService.edit(pd);
		map.put("result", errInfo);
		map.put("pd", pd);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("qualifications:list")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
		page.setPd(pd);
		List<PageData>	varList = qualificationsService.list(page);	//列出Qualifications列表
		for(int i=0; i<varList.size() ; i++) {
			PageData pdVal = varList.get(i);
			PageData pd2 = new PageData();
			pd2.put("FOREIGN_KEY", pdVal.getString("QUALIFICATIONS_ID"));
			pd2.put("TYPE",6);
			List<PageData> hImgs = imgFilesService.listAll(pd2);//隐患图片
			String img = "";
			if(hImgs.size() >0) {
				img = hImgs.get(0).getString("FILEPATH");
			}
			pdVal.put("imgs", hImgs);
		}
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = qualificationsService.findById(pd);	//根据ID读取
		PageData pd2 = new PageData();
		pd2.put("FOREIGN_KEY", pd.getString("QUALIFICATIONS_ID"));
		pd2.put("TYPE",6);
		List<PageData> hImgs = imgFilesService.listAll(pd2);//隐患图片
		map.put("hImgs", hImgs);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("qualifications:del")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			qualificationsService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	@LogAnno(menuType= "双重预防",menuServer= "企业管理",instructionsOperate = "行业资质",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("达标证书名称");	//1
		titles.add("证书有效期");	//2
		titles.add("证书编号");	//3
		titles.add("备注");	//4
		titles.add("企业ID");	//5
		titles.add("添加人");	//6
		titles.add("添加时间");	//7
		titles.add("修改人");	//8
		titles.add("修改时间");	//9
		titles.add("是否删除 1-是  0-否");	//10
		dataMap.put("titles", titles);
		List<PageData> varOList = qualificationsService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("VALIDITYTIME"));	    //2
			vpd.put("var3", varOList.get(i).getString("NUMBER"));	    //3
			vpd.put("var4", varOList.get(i).getString("DESCR"));	    //4
			vpd.put("var5", varOList.get(i).getString("CORPINFO_ID"));	    //5
			vpd.put("var6", varOList.get(i).getString("CREATOR"));	    //6
			vpd.put("var7", varOList.get(i).getString("CREATTIME"));	    //7
			vpd.put("var8", varOList.get(i).getString("OPERATOR"));	    //8
			vpd.put("var9", varOList.get(i).getString("OPERATTIME"));	    //9
			vpd.put("var10", varOList.get(i).getString("ISDELETE"));	    //10
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
