package com.zcloud.controller.education;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.education.TrainingInfoService;
import com.zcloud.service.education.TrainingPlanService;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：培训计划
 * 作者：luoxiaobao
 * 时间：2020-12-28
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/trainingplan")
public class TrainingPlanController extends BaseController {

    @Autowired
    private TrainingPlanService trainingplanService;
    @Autowired
    private TrainingInfoService traininginfoService;
    @Autowired
    private Smb smb;


    @RequestMapping(value = "/goIndexCount")
    // @RequiresPermissions("trainingplan:add")
    @ResponseBody
    public ReturnMap goIndexCount() {
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		PageData data = trainingplanService.goIndexCount(pageData);
        return ReturnMap.ok().put("data",data);
    }

    /**
     * 新增
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/add")
    // @RequiresPermissions("trainingplan:add")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "新增")
    public Object add(@RequestParam(value = "file", required = false) MultipartFile file) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("TRAININGPLAN_ID", this.get32UUID());    //主键
        pd.put("CREATOR", Jurisdiction.getUsername());    //添加人
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
        pd.put("ISDELETE", "0");    //是否删除 1-是  0-否
        if (null != file && !file.isEmpty()) {
            String ffile = DateUtil.getDays();
//			String filePath = PathUtil.getProjectpath() + Const.FILEPATHFILE + ffile;	//文件上传路径
//			String fileName = FileUpload.fileUp(file, filePath, this.get32UUID());				//执行上传
            String fileName = this.get32UUID() + file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
            smb.sshSftp(file, fileName, Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile);
            pd.put("FILEPATH", Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile + "/" + fileName);
        }
        trainingplanService.save(pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 删除
     *
     * @param out
     * @throws Exception
     */
    @RequestMapping(value = "/delete")
    // @RequiresPermissions("trainingplan:del")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "删除")
    public Object delete() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        Page page = new Page();
        page.setPd(pd);
        List<PageData> list = traininginfoService.list(page);
        if(list.size() > 0){
            String code = "201";
            map.put("code", code);
        }else{
            pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
            pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
            trainingplanService.delete(pd);
        }
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/edit")
    // @RequiresPermissions("trainingplan:edit")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "修改")
    public Object edit(@RequestParam(value = "file", required = false) MultipartFile file) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();

        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        if (null != file && !file.isEmpty()) {
            String ffile = DateUtil.getDays();
//			String filePath = PathUtil.getProjectpath() + Const.FILEPATHFILE + ffile;	//文件上传路径
//			String fileName = FileUpload.fileUp(file, filePath, this.get32UUID());				//执行上传
            String fileName = this.get32UUID() + file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
            smb.sshSftp(file, fileName, Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile);
            pd.put("FILEPATH", Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile + "/" + fileName);
        }
        trainingplanService.edit(pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/list")
    // @RequiresPermissions("trainingplan:list")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "列表")
    public Object list(Page page) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String KEYWORDS = pd.getString("KEYWORDS");                        //关键词检索条件
        if (Tools.notEmpty(KEYWORDS)) pd.put("KEYWORDS", KEYWORDS.trim());
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
        page.setPd(pd);
        List<PageData> varList = trainingplanService.list(page);    //列出TrainingPlan列表
        if (varList != null && varList.size() > 0) {
            for (PageData var : varList) {
                if (var.get("FILEPATH") != null && Tools.notEmpty(var.getString("FILEPATH").toString())) {
                    String suffix = var.get("FILEPATH").toString().substring(var.get("FILEPATH").toString().lastIndexOf(".") + 1);
                    var.put("extension_name", suffix);
                }

            }
        }
        map.put("varList", varList);
        map.put("page", page);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去修改页面获取数据
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goEdit")
    // @RequiresPermissions("trainingplan:edit")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "去修改页面获取数据")
    public Object goEdit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd = trainingplanService.findById(pd);    //根据ID读取
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 批量删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/deleteAll")
    // @RequiresPermissions("trainingplan:del")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "批量删除")
    public Object deleteAll() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String DATA_IDS = pd.getString("DATA_IDS");
        if (Tools.notEmpty(DATA_IDS)) {
            String ArrayDATA_IDS[] = DATA_IDS.split(",");
            trainingplanService.deleteAll(ArrayDATA_IDS);
            errInfo = "success";
        } else {
            errInfo = "error";
        }
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 导出到excel
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/excel")
    // @RequiresPermissions("toExcel")
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "导出到excel")
    public ModelAndView exportExcel() throws Exception {
        ModelAndView mv = new ModelAndView();
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> dataMap = new HashMap<String, Object>();
        List<String> titles = new ArrayList<String>();
        titles.add("计划名称");    //1
        titles.add("培训地点");    //2
        titles.add("计划开始时间");    //3
        titles.add("计划结束时间");    //4
        titles.add("培训内容");    //5
        titles.add("附件路径");    //6
        titles.add("备注");    //7
        titles.add("企业ID");    //8
        titles.add("添加人");    //9
        titles.add("添加时间");    //10
        titles.add("修改人");    //11
        titles.add("修改时间");    //12
        titles.add("是否删除 1-是  0-否");    //13
        dataMap.put("titles", titles);
        List<PageData> varOList = trainingplanService.listAll(pd);
        List<PageData> varList = new ArrayList<PageData>();
        for (int i = 0; i < varOList.size(); i++) {
            PageData vpd = new PageData();
            vpd.put("var1", varOList.get(i).getString("PLANNAME"));        //1
            vpd.put("var2", varOList.get(i).getString("ADDRESS"));        //2
            vpd.put("var3", varOList.get(i).getString("STARTTIME"));        //3
            vpd.put("var4", varOList.get(i).getString("ENDTIME"));        //4
            vpd.put("var5", varOList.get(i).getString("CONTENT"));        //5
            vpd.put("var6", varOList.get(i).getString("FILEPATH"));        //6
            vpd.put("var7", varOList.get(i).getString("PLANDESC"));        //7
            vpd.put("var8", varOList.get(i).getString("CORPINFO_ID"));        //8
            vpd.put("var9", varOList.get(i).getString("CREATOR"));        //9
            vpd.put("var10", varOList.get(i).getString("CREATTIME"));        //10
            vpd.put("var11", varOList.get(i).getString("OPERATOR"));        //11
            vpd.put("var12", varOList.get(i).getString("OPERATTIME"));        //12
            vpd.put("var13", varOList.get(i).getString("ISDELETE"));        //13
            varList.add(vpd);
        }
        dataMap.put("varList", varList);
        ObjectExcelView erv = new ObjectExcelView();
        mv = new ModelAndView(erv, dataMap);
        return mv;
    }


    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/getPlanList")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "教育培训", instructionsOperate = "培训计划", instructionsType = "列表")
    public Object getPlanList() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
        List<PageData> varList = trainingplanService.getPlanList(pd);    //列出TrainingPlan列表
        map.put("varList", varList);
        map.put("result", errInfo);
        return map;
    }

}
