package com.zcloud.controller.healthmanagement;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.healthmanagement.HealthRecordsService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：职业卫生档案
 * 作者：luoxiaobao
 * 时间：2022-06-01
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/healthrecords")
public class HealthRecordsController extends BaseController {

	@Autowired
	private HealthRecordsService healthrecordsService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("healthrecords:add")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("HEALTHRECORDS_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		healthrecordsService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("healthrecords:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		healthrecordsService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("healthrecords:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		healthrecordsService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("healthrecords:list")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());

		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
//		pd.put("ISMAIN", Jurisdiction.getIS_MAIN());
//		pd.put("ISSUPERVISE", Jurisdiction.getISSUPERVISE());
//		pd.put("DEPARTMENT_ID", Jurisdiction.getDEPARTMENT_ID());
		String DEPTIDS = pd.getString("DEPARTMENT_ID");
		if(Tools.notEmpty(DEPTIDS)) {
			String DEPT_IDS[] = DEPTIDS.split(",");
			pd.put("DEPT_IDS", DEPT_IDS);
		}

		page.setPd(pd);
		List<PageData>	varList = healthrecordsService.list(page);	//列出HealthRecords列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("healthrecords:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = healthrecordsService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("healthrecords:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			healthrecordsService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
//	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业卫生档案",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String[] ArrayDATA_IDS = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS",ArrayDATA_IDS);
//			occupationalhealthService.listOut(pd);
		}
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("姓名");	//1
		titles.add("所属部门");	//2
		titles.add("检查时间");	//3
		titles.add("检查机构");	//4
		titles.add("检查情况");	//5
		titles.add("在岗情况");	//6
//		titles.add("添加人");	//7
//		titles.add("添加时间");	//8
//		titles.add("修改人");	//9
//		titles.add("修改时间");	//10
//		titles.add("是否删除");	//11
		titles.add("企业名称");	//12
		titles.add("备注");	//13
		titles.add("上岗时间");	//14
		titles.add("离岗时间");	//15
		titles.add("岗位检查情况");	//23
		titles.add("在岗检查情况");	//16
		titles.add("离岗检查情况");	//17
		titles.add("备注");	//24
		titles.add("确认日期");	//18
		titles.add("诊断疾病名称");	//19
		titles.add("治疗情况");	//20
		titles.add("备注");	//25
		titles.add("职业禁忌证");	//21
		titles.add("作业性质");	//22
		titles.add("检查机构");	//21
		titles.add("检查时间");	//22



		dataMap.put("titles", titles);
		List<PageData> varOList = healthrecordsService.listOut(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("DEPT_NAME_ALL"));	    //2
			vpd.put("var3", varOList.get(i).getString("CHECKTIME"));	    //3
			vpd.put("var4", varOList.get(i).getString("CHECKAGENT"));	    //4
			vpd.put("var5", varOList.get(i).getString("CHECKOUT"));	    //5
			vpd.put("var6", varOList.get(i).getString("ONSITUATION"));	    //6
//			vpd.put("var7", varOList.get(i).getString("CREATOR"));	    //7
//			vpd.put("var8", varOList.get(i).getString("CREATTIME"));	    //8
//			vpd.put("var9", varOList.get(i).getString("OPERATOR"));	    //9
//			vpd.put("var10", varOList.get(i).getString("OPERATTIME"));	    //10
//			vpd.put("var11", varOList.get(i).getString("ISDELETE"));	    //11
			vpd.put("var7", varOList.get(i).getString("CORP_NAME"));	    //12
			vpd.put("var8", varOList.get(i).getString("REMARKS"));	    //13
			vpd.put("var9", varOList.get(i).getString("STARTINGTIME"));	    //14
			vpd.put("var10", varOList.get(i).getString("OUTTIME"));	    //15
			vpd.put("var11", varOList.get(i).getString("POSTINSPECTION"));	    //23
			vpd.put("var12", varOList.get(i).getString("ONINSPECTION"));	    //16
			vpd.put("var13", varOList.get(i).getString("OUTINSPECTION"));	    //17
			vpd.put("var14", varOList.get(i).getString("REMARKS2"));	    //24
			vpd.put("var15", varOList.get(i).getString("CONFIRMATIONTIME"));	    //18
			vpd.put("var16", varOList.get(i).getString("DISEASENAME"));	    //19
			vpd.put("var17", varOList.get(i).getString("TREATMENT"));	    //20
			vpd.put("var18", varOList.get(i).getString("REMARKS3"));	    //25
			vpd.put("var19", varOList.get(i).getString("CONTRAINDICATION"));	    //21
			vpd.put("var20", varOList.get(i).getString("NATURE"));	    //22
			vpd.put("var21", varOList.get(i).getString("CHECKAGENT2"));	    //21
			vpd.put("var22", varOList.get(i).getString("CHECKTIME2"));	    //22

			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
