package com.zcloud.controller.healthmanagement;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.healthmanagement.OccupationalHazardService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：职业病危害因素
 * 作者：luoxiaobao
 * 时间：2022-05-31
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/occupationalhazard")
public class OccupationalHazardController extends BaseController {

	@Autowired
	private OccupationalHazardService occupationalhazardService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("occupationalhazard:add")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OCCUPATIONALHAZARD_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		occupationalhazardService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("occupationalhazard:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		occupationalhazardService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("occupationalhazard:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		occupationalhazardService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("occupationalhazard:list")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		page.setPd(pd);
		List<PageData>	varList = occupationalhazardService.list(page);	//列出OccupationalHazard列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("occupationalhazard:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = occupationalhazardService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("occupationalhazard:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			occupationalhazardService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
//	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "综合管理",menuServer= "职业健康管理",instructionsOperate = "职业病危害因素",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String[] ArrayDATA_IDS = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS",ArrayDATA_IDS);
//			occupationalhealthService.listOut(pd);
		}
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("职业病危害因素名称");	//1
		titles.add("检测时间");	//2
		titles.add("检测机构");	//3
		titles.add("地点");	//4
		titles.add("是否超标");	//5
//		titles.add("添加人");	//6
//		titles.add("添加时间");	//7
//		titles.add("修改人");	//8
//		titles.add("修改时间");	//9
//		titles.add("是否删除");	//10
		titles.add("企业名称");	//11
		titles.add("检测情况");	//12
		titles.add("预防措施");	//13
		dataMap.put("titles", titles);
		List<PageData> varOList = occupationalhazardService.listOut(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("DETECTIONTIME"));	    //2
			vpd.put("var3", varOList.get(i).getString("MECHANISM"));	    //3
			vpd.put("var4", varOList.get(i).getString("LOCATION"));	    //4
			vpd.put("var5", varOList.get(i).getString("EXCESSIVE"));	    //5
//			vpd.put("var6", varOList.get(i).getString("CREATOR"));	    //6
//			vpd.put("var7", varOList.get(i).getString("CREATTIME"));	    //7
//			vpd.put("var8", varOList.get(i).getString("OPERATOR"));	    //8
//			vpd.put("var9", varOList.get(i).getString("OPERATTIME"));	    //9
//			vpd.put("var10", varOList.get(i).getString("ISDELETE"));	    //10
			vpd.put("var6", varOList.get(i).getString("CORP_NAME"));	    //11
			vpd.put("var7", varOList.get(i).getString("DETECTION"));	    //12
			vpd.put("var8", varOList.get(i).getString("PRECAUTIONARY"));	    //13
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
