package com.zcloud.controller.majordangersource;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.majordangersource.MajorDangerSourceLogService;
import com.zcloud.service.majordangersource.MajorDangerSourceService;
import com.zcloud.service.majordangersource.MonitoringDeviceDisableService;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.util.*;

/**
 * 说明：重大危险源
 * 作者：luoxiaobao
 * 时间：2022-03-22
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/majordangersource")
public class MajorDangerSourceController extends BaseController {

	@Autowired
	private MajorDangerSourceService majordangersourceService;

	@Autowired
	private MajorDangerSourceLogService majordangersourcelogService;
	@Autowired
	private MonitoringDeviceDisableService monitoringdevicedisableService;
	@Autowired
	private Smb smb;

	/**统计
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/dangerSourceIndex")
	@ResponseBody
	public ReturnMap dangerSourceIndex (){
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		return ReturnMap.ok().put("data", majordangersourceService.dangerSourceIndex(pageData));
	}


	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("majordangersource:add")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "新增")
	public Object add(@RequestParam(value="file",required=false) MultipartFile file) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("MAJORDANGERSOURCE_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		if (null != file && !file.isEmpty()) {
			String ffile = DateUtil.getDays();
			String fileName = this.get32UUID()+file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
			smb.sshSftp(file, fileName, Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile);
			pd.put("BRANCHEMERGENCYPLAN_NAME", file.getOriginalFilename());
			pd.put("BRANCHEMERGENCYPLAN_FILEPATH", Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile + "/" + fileName);
		}
		majordangersourceService.save(pd);
		pd.put("MAJORDANGERSOURCELOG_ID", this.get32UUID());	//主键
		majordangersourcelogService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("majordangersource:del")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		majordangersourceService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("majordangersource:edit")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "修改")
	public Object edit(@RequestParam(value="file",required=false) MultipartFile file) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		if (null != file && !file.isEmpty()) {
			String ffile = DateUtil.getDays();
			String fileName = this.get32UUID()+file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
			smb.sshSftp(file, fileName, Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile);
			pd.put("BRANCHEMERGENCYPLAN_NAME", file.getOriginalFilename());
			pd.put("BRANCHEMERGENCYPLAN_FILEPATH", Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile + "/" + fileName);
		}
		majordangersourceService.edit(pd);
		pd.put("MAJORDANGERSOURCELOG_ID", this.get32UUID());	//主键
		pd.put("CREATOR", pd.getString("OPERATOR"));	//添加人
		pd.put("CREATTIME", pd.getString("OPERATTIME"));	//添加时间
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		majordangersourcelogService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**启用
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/enable")
	// @RequiresPermissions("majordangersource:edit")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "启用")
	public Object enable() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		pd = majordangersourceService.findById(pd);	//根据ID读取
		pd.put("MAJORDANGERSOURCE_STATUS","1");
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		majordangersourceService.edit(pd);
		monitoringdevicedisableService.updateInvalid(pd);	//修改设备停用记录无效
		pd.put("MAJORDANGERSOURCELOG_ID", this.get32UUID());	//主键
		pd.put("CREATOR", pd.getString("OPERATOR"));	//添加人
		pd.put("CREATTIME", pd.getString("OPERATTIME"));	//添加时间
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		majordangersourcelogService.save(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**去阈值设置查看页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goShow")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "去阈值设置查看页面获取数据")
	public Object goShow() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		pd = majordangersourceService.showById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("majordangersource:list")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = majordangersourceService.list(page);	//列出MajorDangerSource列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("majordangersource:edit")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = majordangersourceService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("majordangersource:del")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			List<PageData> pdList = majordangersourceService.findByIds(pd);
			for (PageData d : pdList) {
				smb.deleteFile(d.getString("VIDEOFILES"));
				smb.deleteFile(d.getString("VIDEOCAPTURE"));
			}
			majordangersourceService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("重大危险源名称");	//1
		titles.add("重大危险源类型");	//2
		titles.add("重大危险源地址");	//3
		titles.add("重大危险源位置经度");	//4
		titles.add("重大危险源位置纬度");	//5
		titles.add("重大危险源编号");	//6
		titles.add("投入使用日期");	//7
		titles.add("申报等级");	//8
		titles.add("实际储存量");	//9
		titles.add("最大储量");	//10
		titles.add("管控措施");	//11
		titles.add("分公司应急预案名称");	//12
		titles.add("分公司应急预案文件");	//13
		titles.add("责任人姓名");	//14
		titles.add("联系方式");	//15
		titles.add("是否删除(0:有效 1：删除)");	//16
		titles.add("添加人");	//17
		titles.add("添加时间");	//18
		titles.add("修改人");	//19
		titles.add("修改时间");	//20
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = majordangersourceService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("MAJORDANGERSOURCE_NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("MAJORDANGERSOURCE_TYPE"));	    //2
			vpd.put("var3", varOList.get(i).getString("MAJORDANGERSOURCE_ADDRESS"));	    //3
			vpd.put("var4", varOList.get(i).getString("MAJORDANGERSOURCE_LONGITUDE"));	    //4
			vpd.put("var5", varOList.get(i).getString("MAJORDANGERSOURCE_LATITUDE"));	    //5
			vpd.put("var6", varOList.get(i).getString("MAJORDANGERSOURCE_NUMBER"));	    //6
			vpd.put("var7", varOList.get(i).getString("USE_DATE"));	    //7
			vpd.put("var8", varOList.get(i).getString("DECLARATION_LEVEL"));	    //8
			vpd.put("var9", varOList.get(i).get("STORAGE_ACTUAL").toString());	//9
			vpd.put("var10", varOList.get(i).get("STORAGE_MAX").toString());	//10
			vpd.put("var11", varOList.get(i).getString("CONTROL_MEASURES"));	    //11
			vpd.put("var12", varOList.get(i).getString("BRANCHEMERGENCYPLAN_NAME"));	    //12
			vpd.put("var13", varOList.get(i).getString("BRANCHEMERGENCYPLAN_FILEPATH"));	    //13
			vpd.put("var14", varOList.get(i).getString("RESPONSIBLE_PERSON_NAME"));	    //14
			vpd.put("var15", varOList.get(i).getString("RESPONSIBLE_PERSON_PHONE"));	    //15
			vpd.put("var16", varOList.get(i).getString("ISDELETE"));	    //16
			vpd.put("var17", varOList.get(i).getString("CREATOR"));	    //17
			vpd.put("var18", varOList.get(i).getString("CREATTIME"));	    //18
			vpd.put("var19", varOList.get(i).getString("OPERATOR"));	    //19
			vpd.put("var20", varOList.get(i).getString("OPERATTIME"));	    //20
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

	/**下载
	 * @param response
	 * @throws Exception
	 */
	@RequestMapping(value="/download")
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "下载")
	public void download(HttpServletResponse response) throws Exception {
		PageData pd = new PageData();
		pd = this.getPageData();
		try {
			pd = majordangersourceService.findById(pd);
			String FILEPATH = pd.getString("BRANCHEMERGENCYPLAN_FILEPATH");
			String FILENAME = pd.getString("BRANCHEMERGENCYPLAN_NAME");
			//本地
//			FileDownload.fileDownload(response, PathUtil.getProjectpath() + FILEPATH, FILENAME);
////			FileDownload.mfFileDownload(response, this.getRequest().getScheme() + "://" + this.getRequest().getServerName() + ":" + this.getRequest().getServerPort() + FILEPATH, FILENAME);	//不好用
			//服务器
			FileDownload.mfFileDownload(response, Const.HTTPFILEURL + FILEPATH, FILENAME);
		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("=========文件下载异常：可能要下载的文件已经没有了=========");
		}
	}


	/**列表（实时监控获取所有的重大危险源）
	 * @throws Exception
	 */
	@RequestMapping(value="/findRealTimeMonitoringListAll")
	// @RequiresPermissions("majordangersource:list")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "实时监控获取所有的重大危险源列表")
	public Object findRealTimeMonitoringListAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData>	varList = majordangersourceService.findRealTimeMonitoringListAll(pd);	//列出MajorDangerSource列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}


	/**展示（获取重大危险源信息及实时监测数据）
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/findRealtimeInfo")
	// @RequiresPermissions("majordangersource:edit")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "最大危险源管理",instructionsType = "获取重大危险源信息及实时监测数据展示")
	public Object findRealtimeInfo() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = majordangersourceService.findRealtimeInfo(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}
}
