package com.zcloud.controller.offduty;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.corp.CorpInfoService;
import com.zcloud.service.offduty.OffDutySetupService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：离岗设置
 * 作者：luoxiaobao
 * 时间：2021-06-11
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/offdutySetup")
public class OffDutySetupController extends BaseController {

	@Autowired
	private OffDutySetupService offdutySetupService;
	@Autowired
	private CorpInfoService corpInfoService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("offdutySetup:add")
	@ResponseBody
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OFFDUTY_SETUP_ID", this.get32UUID());	//主键
		pd.put("ISDELETE", "0");	//是否删除 0 未删除  1已删除
		pd.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
		pd.put("CREATOR", Jurisdiction.getUsername());	//创建人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//创建时间
		offdutySetupService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("offdutySetup:del")
	@ResponseBody
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		offdutySetupService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("offdutySetup:edit")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "离岗设置",instructionsOperate = "离岗设置",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
		offdutySetupService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("offdutySetup:list")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "离岗设置",instructionsOperate = "离岗设置",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
		page.setPd(pd);
		List<PageData> varList = new ArrayList<>();
		varList = offdutySetupService.list(page);	//列出OffDutySetup列表
		if (varList.isEmpty()) {
			PageData var = new PageData();
			var.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
			PageData corp = corpInfoService.findById(pd);
			var.put("CORP_NAME",corp.getString("CORP_NAME"));
			var.put("SETUP_STATE", "1");
			varList.add(var);
		}
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("offdutySetup:edit")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "离岗设置",instructionsOperate = "离岗设置",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = offdutySetupService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("offdutySetup:del")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			offdutySetupService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("用户");	//1
		titles.add("公司");	//2
		titles.add("开始时间");	//3
		titles.add("结束时间");	//4
		titles.add("休班原因");	//5
		titles.add("删除状态 0 -未删除  1- 已删除");	//6
		titles.add("添加人");	//7
		titles.add("创建时间");	//8
		titles.add("修改人");	//9
		titles.add("修改时间");	//10
		dataMap.put("titles", titles);
		List<PageData> varOList = offdutySetupService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("USER_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("CORPINFO_ID"));	    //2
			vpd.put("var3", varOList.get(i).getString("STARTTIME"));	    //3
			vpd.put("var4", varOList.get(i).getString("ENDTIME"));	    //4
			vpd.put("var5", varOList.get(i).getString("DESCR"));	    //5
			vpd.put("var6", varOList.get(i).getString("ISDELETE"));	    //6
			vpd.put("var7", varOList.get(i).getString("CREATOR"));	    //7
			vpd.put("var8", varOList.get(i).getString("CREATTIME"));	    //8
			vpd.put("var9", varOList.get(i).getString("OPERATOR"));	    //9
			vpd.put("var10", varOList.get(i).getString("OPERATTIME"));	    //10
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/editSetup")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "离岗设置",instructionsOperate = "离岗设置",instructionsType = "修改设置")
	public Object editSetup() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
		if ("".equals(pd.getString("OFFDUTY_SETUP_ID"))) {
			pd.put("OFFDUTY_SETUP_ID", this.get32UUID());	//主键
			pd.put("ISDELETE", "0");	//是否删除 0 未删除  1已删除
			pd.put("CREATOR", Jurisdiction.getUsername());	//创建人
			pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//创建时间
			offdutySetupService.save(pd);
		} else {
			offdutySetupService.edit(pd);
		}
		map.put("result", errInfo);
		return map;
	}

}
