package com.zcloud.controller.risk;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.risk.RiskCheckItemService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：风险点检查项
 * 作者：luoxiaobao
 * 时间：2020-12-30
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/riskcheckitem")
public class RiskCheckItemController extends BaseController {

	@Autowired
	private RiskCheckItemService riskcheckitemService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("RISKCHECKITEM_ID", this.get32UUID());	//主键
		pd.put("ISDELETE", "0");	//是否删除
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//创建时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		riskcheckitemService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@ResponseBody
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		riskcheckitemService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "风险管控",instructionsOperate = "风险管控台账",instructionsType = "配置修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		riskcheckitemService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "风险管控",instructionsOperate = "风险管控台账",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业
		page.setPd(pd);
		List<PageData>	varList = riskcheckitemService.list(page);	//列出RiskCheckItem列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/itemlistPage")
	@ResponseBody
	public Object itemlistPage(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业
		page.setPd(pd);
		List<PageData>	varList = riskcheckitemService.itemlistPage(page);	//列出RiskCheckItem列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/itemlistAll")
	@ResponseBody
	@LogAnno(menuType= "双重预防",menuServer= "隐患排查",instructionsOperate = "清单排查",instructionsType = "列表")
	public Object itemlistAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		Set<String> idsSet = new HashSet<>();
		if(pd.get("otherIds") != null && Tools.notEmpty(pd.get("otherIds").toString())) {
			String[] idsArray = pd.get("otherIds").toString().split(",");
//			pd.put("idsArray", idsArray);
			idsSet.addAll(Arrays.asList(idsArray));
		}
		if(pd.get("checkIds") != null && Tools.notEmpty(pd.get("checkIds").toString())) {
			String[] checkIdsArray = pd.get("checkIds").toString().split(",");
//			pd.put("checkIdsArray", checkIdsArray);
			idsSet.addAll(Arrays.asList(checkIdsArray));
		}
		if (idsSet.size() > 0) {
			pd.put("idsArray", idsSet.toArray());
		}
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业
		List<PageData>	varList = riskcheckitemService.listAll(pd);	//列出RiskCheckItem列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}

	/**
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/queryRiskCheck")
	@ResponseBody
	public Object queryRiskCheck() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> varList = new ArrayList<PageData>();
		if(pd.get("IDS") != null && Tools.notEmpty(pd.get("IDS").toString())) {
			String[] idsArray = pd.get("IDS").toString().split(",");
			pd.put("idsArray", idsArray);
			varList = riskcheckitemService.queryRiskCheck(pd);
		}
//		List<PageData>	varList = riskcheckitemService.listAll(pd);	//列出RiskCheckItem列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = riskcheckitemService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			riskcheckitemService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("风险点（单元）");	//1
		titles.add("检查内容");	//2
		titles.add("是否删除");	//3
		titles.add("添加人");	//4
		titles.add("创建时间");	//5
		titles.add("修改人");	//6
		titles.add("修改时间");	//7
		dataMap.put("titles", titles);
		List<PageData> varOList = riskcheckitemService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("RISKPOINT_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("CHECK_CONTENT"));	    //2
			vpd.put("var3", varOList.get(i).get("ISDELETE").toString());	//3
			vpd.put("var4", varOList.get(i).getString("CREATOR"));	    //4
			vpd.put("var5", varOList.get(i).getString("CREATTIME"));	    //5
			vpd.put("var6", varOList.get(i).getString("OPERATOR"));	    //6
			vpd.put("var7", varOList.get(i).getString("OPERATTIME"));	    //7
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
