package com.zcloud.controller.safetyInvestment;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.safetyInvestment.SafetyInvestmentUseService;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：安全投入使用
 * 作者：luoxiaobao
 * 时间：2022-05-16
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/safetyinvestmentuse")
public class SafetyInvestmentUseController extends BaseController {

    @Autowired
    private SafetyInvestmentUseService safetyinvestmentuseService;

    /**
     * 新增
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/add")
    // @RequiresPermissions("safetyinvestmentuse:add")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "新增")
    public Object add() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("SAFETYINVESTMENTUSE_ID", this.get32UUID());    //主键
        pd.put("CREATOR", Jurisdiction.getUsername());    //添加人
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("ISDELETE", "0");    //是否删除 1-是  0-否
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        safetyinvestmentuseService.save(pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 删除
     *
     * @param out
     * @throws Exception
     */
    @RequestMapping(value = "/delete")
    // @RequiresPermissions("safetyinvestmentuse:del")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "删除")
    public Object delete() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        safetyinvestmentuseService.delete(pd);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/edit")
    // @RequiresPermissions("safetyinvestmentuse:edit")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "修改")
    public Object edit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        safetyinvestmentuseService.edit(pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/list")
    // @RequiresPermissions("safetyinvestmentuse:list")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "列表")
    public Object list(Page page) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String KEYWORDS = pd.getString("KEYWORDS");                        //关键词检索条件
        if (Tools.notEmpty(KEYWORDS)) pd.put("KEYWORDS", KEYWORDS.trim());
        page.setPd(pd);
        List<PageData> varList = safetyinvestmentuseService.list(page);    //列出SafetyInvestmentUse列表
        map.put("varList", varList);
        map.put("page", page);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/listAll")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "列表")
    public Object listAll() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        List<PageData> varList = safetyinvestmentuseService.listAll(pd);    //列出SafetyInvestmentUse列表
        map.put("varList", varList);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去修改页面获取数据
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goEdit")
    // @RequiresPermissions("safetyinvestmentuse:edit")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "去修改页面获取数据")
    public Object goEdit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd = safetyinvestmentuseService.findById(pd);    //根据ID读取
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 批量删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/deleteAll")
    // @RequiresPermissions("safetyinvestmentuse:del")
    @ResponseBody
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "批量删除")
    public Object deleteAll() throws Exception {
        PageData pd = this.getPageData();
        String DATA_IDS = pd.getString("DATA_IDS");
        if (Tools.isEmpty(DATA_IDS)) {
            return ReturnMap.error("请联系管理员");
        }
        String ArrayDATA_IDS[] = DATA_IDS.split(",");
        safetyinvestmentuseService.deleteAll(ArrayDATA_IDS);
		return ReturnMap.ok();
    }

    /**
     * 导出到excel
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/excel")
    // @RequiresPermissions("toExcel")
    @LogAnno(menuType = "综合管理", menuServer = "安全投入", instructionsOperate = "安全生产费用提取和使用管理", instructionsType = "导出到excel")
    public ModelAndView exportExcel() throws Exception {
        ModelAndView mv = new ModelAndView();
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> dataMap = new HashMap<String, Object>();
        List<String> titles = new ArrayList<String>();
        titles.add("使用时间");    //1
        titles.add("使用类型");    //2
        titles.add("金额");    //3
        titles.add("用途摘要");    //4
        titles.add("费用项目");    //5
        titles.add("是否删除");    //6
        titles.add("添加人");    //7
        titles.add("添加时间");    //8
        titles.add("修改人");    //9
        titles.add("修改时间");    //10
        dataMap.put("titles", titles);
        List<PageData> varOList = safetyinvestmentuseService.listAll(pd);
        List<PageData> varList = new ArrayList<PageData>();
        for (int i = 0; i < varOList.size(); i++) {
            PageData vpd = new PageData();
            vpd.put("var1", varOList.get(i).getString("USE_DATE"));        //1
            vpd.put("var2", varOList.get(i).getString("USE_TYPE"));        //2
            vpd.put("var3", varOList.get(i).get("AMOUNT").toString());    //3
            vpd.put("var4", varOList.get(i).getString("PURPOSESUMMARY"));        //4
            vpd.put("var5", varOList.get(i).getString("TYPE"));        //5
            vpd.put("var6", varOList.get(i).get("ISDELETE").toString());    //6
            vpd.put("var7", varOList.get(i).getString("CREATOR"));        //7
            vpd.put("var8", varOList.get(i).getString("CREATTIME"));        //8
            vpd.put("var9", varOList.get(i).getString("OPERATOR"));        //9
            vpd.put("var10", varOList.get(i).getString("OPERATTIME"));        //10
            varList.add(vpd);
        }
        dataMap.put("varList", varList);
        ObjectExcelView erv = new ObjectExcelView();
        mv = new ModelAndView(erv, dataMap);
        return mv;
    }

}
