package com.zcloud.controller.specialoperation;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.specialoperation.PersonnelManagementService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：特种作业人员管理
 * 作者：luoxiaobao
 * 时间：2022-06-16
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/personnelmanagement")
public class AppPersonnelManagementController extends BaseController {

	@Autowired
	private PersonnelManagementService personnelmanagementService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("PERSONNELMANAGEMENT_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		personnelmanagementService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		personnelmanagementService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		personnelmanagementService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", pd.get("CORPINFO_ID"));	//企业ID
		page.setPd(pd);
		List<PageData>	varList = personnelmanagementService.namelist(pd);	//列出PersonnelManagement列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = personnelmanagementService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			personnelmanagementService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**判断特种作业证书编号是否存在
	 * @return
	 */
	@RequestMapping(value="/hasCertificate")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "判断特种作业证书编号是否存在")
	public Object hasCertificate() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		if(personnelmanagementService.findByCertificate(pd) != null){
			map.put("msg","特种作业证书编号已存在");
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}
	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	@LogAnno(menuType= "综合管理",menuServer= "特种作业",instructionsOperate = "特种作业人员管理",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("添加人");	//1
		titles.add("添加单位");	//2
		titles.add("单位名称");	//3
		titles.add("人员类型");	//4
		titles.add("作业类别");	//5
		titles.add("操作项目");	//6
		titles.add("姓名");	//7
		titles.add("性别");	//8
		titles.add("特种作业证书编号");	//9
		titles.add("复审时间");	//10
		titles.add("手机号码");	//11
		titles.add("身份证号码");	//12
		titles.add("发证机关");	//13
		titles.add("有效期");	//14
		titles.add("添加时间");	//15
		titles.add("修改人");	//16
		titles.add("修改时间");	//17
		titles.add("是否删除");	//18
		titles.add("企业ID");	//19
		dataMap.put("titles", titles);
		List<PageData> varOList = personnelmanagementService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("CREATOR"));	    //1
			vpd.put("var2", varOList.get(i).getString("ADDUNITS"));	    //2
			vpd.put("var3", varOList.get(i).getString("UNITS_NAME"));	    //3
			vpd.put("var4", varOList.get(i).getString("TYPE"));	    //4
			vpd.put("var5", varOList.get(i).getString("JOB_TYPE"));	    //5
			vpd.put("var6", varOList.get(i).getString("OPERATIONITEM"));	    //6
			vpd.put("var7", varOList.get(i).getString("NAME"));	    //7
			vpd.put("var8", varOList.get(i).getString("SEX"));	    //8
			vpd.put("var9", varOList.get(i).getString("CERTIFICATE_NUM"));	    //9
			vpd.put("var10", varOList.get(i).getString("REVIEWTIME"));	    //10
			vpd.put("var11", varOList.get(i).getString("PHONENUM"));	    //11
			vpd.put("var12", varOList.get(i).getString("IDENTITYCARD"));	    //12
			vpd.put("var13", varOList.get(i).getString("LICENSING"));	    //13
			vpd.put("var14", varOList.get(i).getString("VALID"));	    //14
			vpd.put("var15", varOList.get(i).getString("CREATETIME"));	    //15
			vpd.put("var16", varOList.get(i).getString("OPERATOR"));	    //16
			vpd.put("var17", varOList.get(i).getString("OPERATTIME"));	    //17
			vpd.put("var18", varOList.get(i).getString("ISDELETE"));	    //18
			vpd.put("var19", varOList.get(i).getString("CORPINFO_ID"));	    //19
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
