package com.zcloud.controller.study;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.study.TempStudyService;
import com.zcloud.service.study.TempStudyUsersService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：临时学习任务
 * 作者：luoxiaobao
 * 时间：2022-05-18
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/tempstudy")
public class TempStudyController extends BaseController {

	@Autowired
	private TempStudyService tempstudyService;
	@Autowired
	private TempStudyUsersService tempStudyUsersService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@Transactional
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("TEMPSTUDY_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE",0);	//是否删除(0:有效 1：删除)
		pd.put("STATUS",0);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID

		if (pd.get("STUDY_USER_IDS") != null && !pd.get("STUDY_USER_IDS").equals("")) {
			String[] userids = pd.get("STUDY_USER_IDS").toString().split(",");
			for (String id : userids) {
				PageData user = new PageData();
				user.put("TEMPSTUDYUSERS_ID", this.get32UUID());
				user.put("TEMPSTUDY_ID", pd.get("TEMPSTUDY_ID"));
				user.put("USER_ID",id);
				user.put("STATUS",0);
				// 保存所选的课件
				tempStudyUsersService.save(user);
			}
			pd.put("USER_NUM",userids.length);
		}

		tempstudyService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		tempstudyService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@ResponseBody
	@Transactional
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "启用或禁用")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		Object status = pd.get("STATUS");
		pd = tempstudyService.findById(pd);
		pd.put("STATUS",status);
//		tempStudyUsersService.delete(pd);
//		if (pd.get("STUDY_USER_IDS") != null && !pd.get("STUDY_USER_IDS").equals("")) {
//			String[] userids = pd.get("STUDY_USER_IDS").toString().split(",");
//			for (String id : userids) {
//				PageData user = new PageData();
//				user.put("TEMPSTUDYUSERS_ID", this.get32UUID());
//				user.put("TEMPSTUDY_ID", pd.get("TEMPSTUDY_ID"));
//				user.put("USER_ID",id);
//				user.put("STATUS",0);
//				// 保存所选的课件
//				tempStudyUsersService.save(user);
//			}
//			pd.put("USER_NUM",userids.length);
//		}
		tempstudyService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = tempstudyService.list(page);	//列出TempStudy列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/studentList")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "列表")
	public Object studentList(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		page.setPd(pd);
		List<PageData>	varList = tempStudyUsersService.list(page);	//列出TempStudy列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = tempstudyService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			tempstudyService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "综合管理",menuServer= "学习园地",instructionsOperate = "学习园地",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("企业");	//1
		titles.add("名称");	//2
		titles.add("课件类型");	//3
		titles.add("课件ID");	//4
		titles.add("学习类型");	//5
		titles.add("状态");	//6
		titles.add("删除");	//7
		titles.add("添加人");	//8
		titles.add("添加时间");	//9
		titles.add("修改人");	//10
		titles.add("修改时间");	//11
		dataMap.put("titles", titles);
		List<PageData> varOList = tempstudyService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("CORPINFO_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("NAME"));	    //2
			vpd.put("var3", varOList.get(i).getString("COURSEWARE_TYPE"));	    //3
			vpd.put("var4", varOList.get(i).getString("COURSEWARE_ID"));	    //4
			vpd.put("var5", varOList.get(i).getString("STUDY_TYPE"));	    //5
			vpd.put("var6", varOList.get(i).get("STATUS").toString());	//6
			vpd.put("var7", varOList.get(i).get("ISDELETE").toString());	//7
			vpd.put("var8", varOList.get(i).getString("CREATOR"));	    //8
			vpd.put("var9", varOList.get(i).getString("CREATTIME"));	    //9
			vpd.put("var10", varOList.get(i).getString("OPERATOR"));	    //10
			vpd.put("var11", varOList.get(i).getString("OPERATTIME"));	    //11
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
