package com.zcloud.controller.task;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.curriculum.CoursepapersService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：课程试卷管理
 * 作者：luoxiaobao
 * 时间：2021-07-03
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/coursepapers")
public class AppCoursepapersController extends BaseController {

	@Autowired
	private CoursepapersService coursepapersService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions( value = {"coursepapers:add", "curriculum:add"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("COURSEPAPERS_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		coursepapersService.save(pd);

		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions( value = {"coursepapers:del", "curriculum:del"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		coursepapersService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions( value = {"coursepapers:edit", "curriculum:edit"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		coursepapersService.edit(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions( value = {"coursepapers:list", "curriculum:list"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = coursepapersService.list(page);	//列出Coursepapers列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions( value = {"coursepapers:edit", "curriculum:edit"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = coursepapersService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**通过课程ID获取试卷相关数据（试卷、试卷试题）
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/checkCurriculumExam")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "通过课程ID获取试卷相关数据")
	public Object checkCurriculumExam() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = coursepapersService.checkCurriculumExam(pd);	//通过课程ID获取数据
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**通过课程ID获取试卷相关数据（试卷、试卷试题）
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/findByCurriculumExam")
//	// @RequiresPermissions( value = {"coursepapers:edit", "curriculum:edit"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "通过课程ID获取试卷相关数据")
	public Object goEditByCurriculum() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = coursepapersService.findByCurriculumExam(pd);	//通过课程ID获取数据
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions( value = {"coursepapers:del", "curriculum:del"}, logical = Logical.OR)
	@ResponseBody	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			coursepapersService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("课程ID");	//1
		titles.add("试卷名称");	//2
		titles.add("考试时间（开始时间）");	//3
		titles.add("答卷时间（持续时间）");	//4
		titles.add("试卷分数");	//5
		titles.add("适用人员");	//6
		titles.add("试题数量（10、20、50、100）");	//7
		titles.add("试卷状态");	//8
		titles.add("添加人");	//9
		titles.add("添加时间");	//10
		titles.add("修改人");	//11
		titles.add("修改时间");	//12
		titles.add("是否删除(0:有效 1：删除)");	//13
		titles.add("企业ID");	//14
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = coursepapersService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("CURRICULUMID"));	    //1
			vpd.put("var2", varOList.get(i).getString("EXAMNAME"));	    //2
			vpd.put("var3", varOList.get(i).getString("EXAMTIME"));	    //3
			vpd.put("var4", varOList.get(i).getString("ANSWERSHEETTIME"));	    //4
			vpd.put("var5", varOList.get(i).getString("EXAMSCORE"));	    //5
			vpd.put("var6", varOList.get(i).getString("CURRICULUMUSERS"));	    //6
			vpd.put("var7", varOList.get(i).getString("QUESTIONNUM"));	    //7
			vpd.put("var8", varOList.get(i).getString("EXAMSTATE"));	    //8
			vpd.put("var9", varOList.get(i).getString("CREATOR"));	    //9
			vpd.put("var10", varOList.get(i).getString("CREATTIME"));	    //10
			vpd.put("var11", varOList.get(i).getString("OPERATOR"));	    //11
			vpd.put("var12", varOList.get(i).getString("OPERATTIME"));	    //12
			vpd.put("var13", varOList.get(i).get("ISDELETE").toString());	//13
			vpd.put("var14", varOList.get(i).getString("CORPINFO_ID"));	    //14
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/submit")
	// @RequiresPermissions( value = {"coursepapers:edit", "curriculum:edit"}, logical = Logical.OR)
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程试卷管理",instructionsOperate = "课程试卷管理",instructionsType = "修改")
	public Object submit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		coursepapersService.edit(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

}
