package com.zcloud.controller.task;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.task.StudyTaskService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：在线学习考试-任务
 * 作者：luoxiaobao
 * 时间：2021-12-20
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/studytask")
public class AppStudyTaskController extends BaseController {

	@Autowired
	private StudyTaskService studytaskService;

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		page.setPd(pd);
		List<PageData>	varList = studytaskService.list(page);	//列出StudyTask列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @throws Exception
	 */
	@RequestMapping(value="/updateTaskState")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "列表")
	public Object updateTaskState() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", pd.getString("USERNAME"));	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		studytaskService.updateTaskState(pd);
		map.put("result", errInfo);
		return map;
	}











	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("studytask:add")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("STUDYTASK_ID", this.get32UUID());	//主键
		studytaskService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("studytask:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		studytaskService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("studytask:edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		studytaskService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("studytask:edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = studytaskService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("studytask:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			studytaskService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "手机",menuServer= "在线学习考试",instructionsOperate = "在线学习考试",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("学习任务名称");	//1
		titles.add("培训行业类型");	//2
		titles.add("岗位培训类型");	//3
		titles.add("培训开始时间");	//4
		titles.add("培训结束时间");	//5
		titles.add("是否签到");	//6
		titles.add("是否开启防挂机验证");	//7
		titles.add("考试");	//8
		titles.add("人员id");	//9
		titles.add("添加课程IDS");	//10
		titles.add("添加人");	//11
		titles.add("添加时间");	//12
		titles.add("修改人");	//13
		titles.add("修改时间");	//14
		titles.add("是否删除(0:有效 1：删除)");	//15
		titles.add("企业ID");	//16
		dataMap.put("titles", titles);
		List<PageData> varOList = studytaskService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("STUDY_NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("TRAINTYPE"));	    //2
			vpd.put("var3", varOList.get(i).getString("POSTTYPE"));	    //3
			vpd.put("var4", varOList.get(i).getString("PEIXUE_START_TIME"));	    //4
			vpd.put("var5", varOList.get(i).getString("PEIXUE_END_TIME"));	    //5
			vpd.put("var6", varOList.get(i).get("KJ_STATE").toString());	//6
			vpd.put("var7", varOList.get(i).getString("GJ_STATE"));	    //7
			vpd.put("var8", varOList.get(i).getString("STAGEEXAMPAPER_ID"));	    //8
			vpd.put("var9", varOList.get(i).getString("STUDY_USER_ID"));	    //9
			vpd.put("var10", varOList.get(i).getString("STUDY_CURRICULUM_ID"));	    //10
			vpd.put("var11", varOList.get(i).getString("CREATOR"));	    //11
			vpd.put("var12", varOList.get(i).getString("CREATTIME"));	    //12
			vpd.put("var13", varOList.get(i).getString("OPERATOR"));	    //13
			vpd.put("var14", varOList.get(i).getString("OPERATTIME"));	    //14
			vpd.put("var15", varOList.get(i).get("ISDELETE").toString());	//15
			vpd.put("var16", varOList.get(i).getString("CORPINFO_ID"));	    //16
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
