package com.zcloud.controller.task;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.task.StageStudentRelationService;
import com.zcloud.util.*;
import org.apache.commons.lang.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：阶段考试学员关系表
 * 作者：luoxiaobao
 * 时间：2021-10-08
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/stagestudentrelation")
public class StageStudentRelationController extends BaseController {

	@Autowired
	private StageStudentRelationService stagestudentrelationService;
	@Autowired
	private Smb smb;
	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("STAGESTUDENTRELATION_ID", this.get32UUID());	//主键
		pd.put("STAGEEXAMSTATE", "");	//阶段考试状态（1.未开始 2.考试中 3.考试完成 4.未参加）
		pd.put("STAGEEXAMSCORE", "");	//阶段考试得分
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		stagestudentrelationService.save(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@ResponseBody
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		stagestudentrelationService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("stagestudentrelation:edit")
	@ResponseBody
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		stagestudentrelationService.edit(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "考试详情列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = stagestudentrelationService.list(page);	//列出StageStudentRelation列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = stagestudentrelationService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String[] ArrayDATA_IDS = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			stagestudentrelationService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("阶段考试试卷ID");	//1
		titles.add("考试人员ID");	//2
		titles.add("阶段考试状态（1.未开始 2.考试中 3.考试完成 4.未参加）");	//3
		titles.add("阶段考试得分");	//4
		titles.add("添加人");	//5
		titles.add("添加时间");	//6
		titles.add("修改人");	//7
		titles.add("修改时间");	//8
		titles.add("是否删除(0:有效 1：删除)");	//9
		titles.add("企业ID");	//10
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = stagestudentrelationService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("STAGEEXAMPAPER_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("USER_ID"));	    //2
			vpd.put("var3", varOList.get(i).getString("STAGEEXAMSTATE"));	    //3
			vpd.put("var4", varOList.get(i).getString("STAGEEXAMSCORE"));	    //4
			vpd.put("var5", varOList.get(i).getString("CREATOR"));	    //5
			vpd.put("var6", varOList.get(i).getString("CREATTIME"));	    //6
			vpd.put("var7", varOList.get(i).getString("OPERATOR"));	    //7
			vpd.put("var8", varOList.get(i).getString("OPERATTIME"));	    //8
			vpd.put("var9", varOList.get(i).getString("ISDELETE"));	    //9
			vpd.put("var10", varOList.get(i).getString("CORPINFO_ID"));	    //10
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

	/**列表【我的考试】（获取当前用户的所属阶段考试信息）
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/pageDataByUser")
	@ResponseBody
	public Object pageDataByUser(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		pd.put("USER_ID", Jurisdiction.getUSER_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = stagestudentrelationService.pageDataByUser(page);	//列出StageStudentRelation列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**修改（更新学员考试状态）
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/updateStudentState")
//	// @RequiresPermissions("coursestudentrelation:edit")
	@ResponseBody
	public Object updateStudentState() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		stagestudentrelationService.updateStudentState(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**修改（更新学员考试状态）
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/sign")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "我的任务",instructionsType = "更新学员考试状态")
	public Object sign() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();

		if (StringUtils.isNotBlank(pd.getString("USER_SIGN_PATH"))) {
			MultipartFile file = BASE64DecodedMultipartFile.base64ToMultipart(pd.getString("USER_SIGN_PATH"));
			String  ffile = DateUtil.getDays();
			String fileName = this.get32UUID()+file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."));
			smb.sshSftp(file, fileName, Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile);

			pd.put("USER_SIGN_PATH",  Const.FILEPATHFILE + Jurisdiction.getCORPINFO_ID() + "/" + ffile + "/" + fileName);
		}
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		stagestudentrelationService.updateStudentState(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @throws Exception
	 */
	@RequestMapping(value="/listAllByStudyTaskId")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "学员详情列表")
	public Object listAllByStudyTaskId() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData>	varList = stagestudentrelationService.listAll(pd);	//列出StageStudentRelation列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}
	/**列表【我的任务】（获取当前用户的所属任务信息列表）
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/pageTaskByUser")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "我的任务",instructionsType = "获取当前用户的所属任务信息列表")
	public Object pageTaskByUser(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = this.getPageData();
		pd.put("USER_ID", Jurisdiction.getUSER_ID());	//企业ID
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData> varList = stagestudentrelationService.pageTaskByUser(page);    //列出StudyTask列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}
}
