package com.zcloud.controller.task;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.paper.StageExamPaperQuestionService;
import com.zcloud.service.paper.StageexampaperService;
import com.zcloud.service.task.*;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：在线学习考试-任务
 * 作者：luoxiaobao
 * 时间：2021-12-20
 * 官网：www.zcloudchina.com
 */
@Controller
	@RequestMapping("/studytask")
public class StudyTaskController extends BaseController {

	@Autowired
	private StudyTaskService studytaskService;
	@Autowired
	private StageexampaperService stageexampaperService;
	@Autowired
	private StageExamPaperQuestionService stageExamPaperQuestionService;
	@Autowired
	private StageStudentRelationService stageStudentRelationService;
	@Autowired
	private StudytaskCurriculumService studytaskCurriculumService;
	@Autowired
	private StudytaskSignService studytasksignService;
	@Autowired
	private StageExamService stageExamService;
	@Autowired
	private StageExamRecordService stageExamRecordService;


	@RequestMapping(value="/studyIndex")
	@ResponseBody
	public Object studyIndex(){
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		return ReturnMap.ok().put("data",stageExamService.studyIndex(pageData));
	}


//	培训计划

	@RequestMapping(value="/trainingIndex")
	@ResponseBody
	public Object trainingIndex(){
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		PageData data = stageExamService.trainingData(pageData);
		return ReturnMap.ok().put("data",data);
	}
	@RequestMapping(value="/postTypeIndex")
	@ResponseBody
	public Object postTypeIndex(){
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		List<PageData> data = stageExamService.postTypeIndex(pageData);
		return ReturnMap.ok().put("data",data);
	}
	@RequestMapping(value="/getStudyStartIndexData")
	@ResponseBody
	public Object getStudyStartIndexData(){
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		List<PageData> data = stageExamService.getStudyStartIndexData(pageData);
		return ReturnMap.ok().put("varList",data);
	}


	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("studytask:add")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String date = DateUtil.date2Str(new Date());
		pd.put("STUDYTASK_ID", this.get32UUID());	//主键 任务id
		pd.put("STAGEEXAMPAPER_ID", this.get32UUID());	//主键 考试id
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", date);	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", date);	//修改时间
		pd.put("EXAMSTATE", "0");	//试卷状态(0:初始 1：已考试)
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("STATE", "0");	//任务状态 0:未开始，1:开始;2:结束
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
//		pd.put("TRAINTYPE", Jurisdiction.getCORPTRAINTYPE());//企业的培训行业类型

		PageData stPd = studytaskCurriculumService.save(pd); // 任务-课程
		pd.put("SUM_CLASSHOUR",stPd.get("sumCla"));
		pd.put("COURSEWARE_COUNT",stPd.get("sumCount"));
		studytaskService.save(pd); //bus_studytask

		stageexampaperService.saveV2(pd);// 添加考试表 INPUT_ID
		stageExamPaperQuestionService.saveAllV2(pd); // 添加考试表--习题关系表

		stageStudentRelationService.saveFromPagerV2(pd); // 任务-人员

		studytasksignService.saveByStudyTask(pd);//任务--签字信息
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("studytask:del")
	@ResponseBody
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		studytaskService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("studytask:edit")
	@ResponseBody
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		studytaskService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
//	// @RequiresPermissions("studytask:list")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
		page.setPd(pd);
		List<PageData>	varList = studytaskService.list(page);	//列出StudyTask列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = studytaskService.findById(pd);	//根据ID读取
		List<PageData> scurAllList = studytaskService.getcurriculumAllBystudyTaskId(pd); // 任务 -- 课件关系
		map.put("scurAllList", scurAllList);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("studytask:del")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			studytaskService.deleteAll(ArrayDATA_IDS);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("学习任务名称");	//1
		titles.add("培训行业类型");	//2
		titles.add("岗位培训类型");	//3
		titles.add("培训开始时间");	//4
		titles.add("培训结束时间");	//5
		titles.add("是否签到");	//6
		titles.add("是否开启防挂机验证");	//7
		titles.add("考试");	//8
		titles.add("人员id");	//9
		titles.add("添加课程IDS");	//10
		titles.add("添加人");	//11
		titles.add("添加时间");	//12
		titles.add("修改人");	//13
		titles.add("修改时间");	//14
		titles.add("是否删除(0:有效 1：删除)");	//15
		titles.add("企业ID");	//16
		dataMap.put("titles", titles);
		List<PageData> varOList = studytaskService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("STUDY_NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("TRAINTYPE"));	    //2
			vpd.put("var3", varOList.get(i).getString("POSTTYPE"));	    //3
			vpd.put("var4", varOList.get(i).getString("PEIXUE_START_TIME"));	    //4
			vpd.put("var5", varOList.get(i).getString("PEIXUE_END_TIME"));	    //5
			vpd.put("var6", varOList.get(i).get("KJ_STATE").toString());	//6
			vpd.put("var7", varOList.get(i).getString("GJ_STATE"));	    //7
			vpd.put("var8", varOList.get(i).getString("STAGEEXAMPAPER_ID"));	    //8
			vpd.put("var9", varOList.get(i).getString("STUDY_USER_ID"));	    //9
			vpd.put("var10", varOList.get(i).getString("STUDY_CURRICULUM_ID"));	    //10
			vpd.put("var11", varOList.get(i).getString("CREATOR"));	    //11
			vpd.put("var12", varOList.get(i).getString("CREATTIME"));	    //12
			vpd.put("var13", varOList.get(i).getString("OPERATOR"));	    //13
			vpd.put("var14", varOList.get(i).getString("OPERATTIME"));	    //14
			vpd.put("var15", varOList.get(i).get("ISDELETE").toString());	//15
			vpd.put("var16", varOList.get(i).getString("CORPINFO_ID"));	    //16
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}
	/**列表
	 * @throws Exception STUDYTASK_ID
	 */
	@RequestMapping(value="/getAllCourseware")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一期一档",instructionsType = "列表")
	public Object getAllCourseware() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> varList = studytaskService.getAllCourseware(pd);	//列出StudyTask列表
		// 获取学员第二成绩
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @throws Exception STUDYTASK_ID
	 */
	@RequestMapping(value="/getAllcurriculum")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一期一档",instructionsType = "列表")
	public Object getAllcurriculum() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> varList = studytaskService.getAllcurriculum(pd);	//列出StudyTask列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}

	/**试卷
	 * @throws Exception STUDYTASK_ID
	 */
	@RequestMapping(value="/getPaper")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一期一档",instructionsType = "试卷")
	public Object getPaper() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		PageData task = this.studytaskService.findById(pd);
		List<PageData> questionList = stageExamPaperQuestionService.findByExamPaper(task);
		map.put("questionList", questionList);
		map.put("paper",stageexampaperService.findById(task));
		map.put("result", errInfo);
		return map;
	}

	/**获取一人一档试卷
	 * @throws Exception STUDYTASK_ID
	 */
	@RequestMapping(value="/getArchivesPaper")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一期一档",instructionsType = "试卷")
	public Object getArchivesPaper() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		PageData task = this.studytaskService.findById(pd);
		pd.put("STAGEEXAMPAPER_ID",task.getString("STAGEEXAMPAPER_ID"));
		PageData data = stageExamService.findByPaperUser(pd); // 考试成绩 STAGEEXAM_ID
		List<PageData> questionList = new ArrayList<PageData>();
		if(data != null){
			pd.put("STAGEEXAM_ID", data.getString("STAGEEXAM_ID"));
			questionList = stageExamRecordService.findByExam(pd); // 考试详情 STAGEEXAM_ID
			map.put("isExam", "1");
		} else {
			questionList = stageExamPaperQuestionService.findByExamPaper(task);
			map.put("isExam", "0");
		}
//
//		List<PageData> questionList = stageExamRecordService.findByExam(task); // 考试详情 STAGEEXAM_ID
		map.put("questionList", questionList);
		map.put("paper",stageexampaperService.findById(task));
		map.put("result", errInfo);
		return map;
	}


	/**列表
	 * @throws Exception STUDYTASK_ID
	 */
	@RequestMapping(value="/getAllByuserInfo")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "学习详情列表")
	public Object getAllByuserInfo() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> varList = studytaskService.getAllByuserInfo(pd);	//列出StudyTask列表1
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}
	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/userlist")
//	// @RequiresPermissions("studytask:list")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一人一档",instructionsType = "任务列表")
	public Object userlist(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		page.setPd(pd);
		List<PageData>	varList = studytaskService.userlist(page);	//列出StudyTask列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}
	/**列表
	 * @throws Exception STUDYTASK_ID
	 */
	@RequestMapping(value="/getAllCoursewareByHandout")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "档案管理",instructionsOperate = "一期一档",instructionsType = "列表")
	public Object getAllCoursewareByHandout() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> varList = studytaskService.getAllCoursewareByHandout(pd);	//列出StudyTask列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}
	/**修改任务的结束时间和添加人员
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/updateEndTimeAndUser")
	// @RequiresPermissions("studytask:edit")
	@ResponseBody
	@LogAnno(menuType= "教育培训",menuServer= "在线学习与考试",instructionsOperate = "任务管理",instructionsType = "修改任务的结束时间和添加人员")
	public Object updateEndTimeAndUser() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
//		pd.put("STAGEEXAMPAPER_ID", this.get32UUID());	//主键 考试id

		studytaskService.editEndTime(pd);
//		PageData task = studytaskService.findById(pd);
//		task.put("userIds", pd.get("userIds"));
//		task.put("STAGEEXAMPAPER_ID", pd.get("STAGEEXAMPAPER_ID"));
		stageStudentRelationService.saveFromPagerV2(pd); // 任务-人员
		if(pd != null && pd.get("deleteUserIds") != null && Tools.notEmpty(pd.getString("deleteUserIds"))) {
			String[] delReaList = pd.getString("deleteUserIds").split(",");
			for(String delReaId : delReaList) {
				PageData rData = new PageData();

				rData.put("STAGESTUDENTRELATION_ID", delReaId);    //修改人
				rData.put("OPERATOR", pd.getString("OPERATOR"));    //修改人
				rData.put("OPERATTIME", pd.getString("OPERATTIME"));    //修改时间
				stageStudentRelationService.delete(rData);
			}
		}
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @throws Exception
	 */
	@RequestMapping(value="/BIstatistics")
	@ResponseBody
	public Object BIstatistics() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varList = studytaskService.BIstatistics(pd);	//列出StudyTask列表
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}
}

