package com.zcloud.service.eightwork.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.mapper.datasource.eightwork.*;
import com.zcloud.service.eightwork.ElectricityService;
import com.zcloud.service.eightwork.HighworkService;
import com.zcloud.util.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.text.DecimalFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author fangjiakai
 * @date 2024/01/17 11:30
 */
@Service
@Transactional //开启事物
public class ElectricityServiceImpl implements ElectricityService {
    @Autowired
    private HighworkService highworkService;

    @Autowired
    private ElectricityMapper electricityMapper;
    @Autowired
    private EightWorkTaskFlowMapper eightWorkTaskFlowMapper;
    @Autowired
    private EightWorkFlowLogMapper eightWorkFlowLogMapper;
    @Autowired
    private ElectricitySignMapper electricitySignMapper;
    @Autowired
    private ElectricityToMeasuresMapper electricityToMeasuresMapper;
    @Autowired
    private ElectricityGasMapper electricitygasMapper;
    @Autowired
    private EightWorkVideoManagerMapper eightworkvideomanagerMapper;
    @Autowired
    private Smb smb;
    @Autowired
    private SendMessageUtil sendMessageUtil;

    private final String primary_key = "ELECTRICITY_ID";
    private final String work_type = "ELECTRICITY";
    @Override
    @Transactional
    public void save(PageData pd) throws Exception {
        if ("1".equals(pd.get("APPLY_STATUS"))) {
            PageData pd2 = new PageData();
            Calendar calendar = Calendar.getInstance();
            DecimalFormat dft=new DecimalFormat("00");
            int year = calendar.get(Calendar.YEAR);
            String month = dft.format(calendar.get(Calendar.MONTH) + 1);
            String day = dft.format(calendar.get(Calendar.DAY_OF_MONTH));
            pd2.put("CREATDATE",year + "-" + month + "-" + day);
            pd2.put("CORPINFO_ID",pd.get("CORPINFO_ID"));
            pd2 = electricityMapper.getCode(pd2);    //根据ID读取
            String code = "LS" + year + month + day + dft.format((Integer.parseInt(pd2.get("code").toString()) + 1));
            pd.put("CHECK_NO", code);
        }
        pd.put(primary_key, UuidUtil.get32UUID());    //主键
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("ISDELETE", "0");    //是否删除 1-是  0-否
        electricityMapper.save(pd);
        if ("1".equals(pd.get("APPLY_STATUS"))) {
//            PageData flow = getStep(pd.get("TASK_ID"),"1");
            saveLog(pd,pd.getString("CREATOR"),"1");
            PageData flow = getCurrentFlow(pd);
            pd.put("STEP_ID", flow.get("STEP_ID"));
            electricityMapper.editStep(pd);
            if (Tools.notEmpty(pd.getString("SPECIAL_WORK"))) {

            String[] specialWorks = pd.getString("SPECIAL_WORK").split(",");
            if (specialWorks.length != 0) {
                for (int i = 0; i < specialWorks.length; i++) {
                    String[] workNameANo = specialWorks[i].split(" ");
                    highworkService.changeOtherWorkCard(workNameANo, pd.getString("CORPINFO_ID"), "临时用电 " + pd.getString("CHECK_NO"));
                }
            }
            }
            saveNextSigner(pd,flow);
            if (Tools.notEmpty(pd.getString("PLS_ID"))) {
                setPosition(pd);
            }

            // 推送 是否进行气体检测：0否；1是'
            if("1".equals(pd.getString("ISANALYZE"))){
                sendMessageForFinished(pd.getString("CORPINFO_ID"),pd.getString("CREATOR"),"YD_QT",pd.getString("CHECK_NO"),null);
            }
        }
    }

    @Override
    @Transactional
    public void edit(PageData pd) throws Exception {
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        if ("1".equals(pd.get("APPLY_STATUS"))) {
            PageData pd2 = new PageData();
            Calendar calendar = Calendar.getInstance();
            DecimalFormat dft=new DecimalFormat("00");
            int year = calendar.get(Calendar.YEAR);
            String month = dft.format(calendar.get(Calendar.MONTH) + 1);
            String day = dft.format(calendar.get(Calendar.DAY_OF_MONTH));
            pd2.put("CREATDATE",year + "-" + month + "-" + day);
            pd2.put("CORPINFO_ID",pd.get("CORPINFO_ID"));
            pd2 = electricityMapper.getCode(pd2);    //根据ID读取
            String code = "LS" + year + month + day + dft.format((Integer.parseInt(pd2.get("code").toString()) + 1));
            pd.put("CHECK_NO", code);
        }
        electricityMapper.edit(pd);
        if ("1".equals(pd.get("APPLY_STATUS"))) {
            PageData flowx = getCurrentFlow(pd);
            pd.put("STEP_ID", flowx.get("STEP_ID"));
            electricityMapper.editStep(pd);
            if (Tools.notEmpty(pd.getString("SPECIAL_WORK"))) {
                String[] specialWorks = pd.getString("SPECIAL_WORK").split(",");
                if (specialWorks.length != 0) {
                    for (int i = 0; i < specialWorks.length; i++) {
                        String[] workNameANo = specialWorks[i].split(" ");
                        highworkService.changeOtherWorkCard(workNameANo, pd.getString("CORPINFO_ID"), "临时用电 " + pd.getString("CHECK_NO"));
                    }
                }
            }
            PageData flow = getStep(pd.get("TASK_ID"),flowx.get("STEP_ID"));
            saveLog(pd,pd.getString("CREATOR"),"1");
            saveNextSigner(pd,flow);
            if (Tools.notEmpty(pd.getString("PLS_ID"))) {
                setPosition(pd);
            }

            // 推送 是否进行气体检测：0否；1是'
            if("1".equals(pd.getString("ISANALYZE"))){
                sendMessageForFinished(pd.getString("CORPINFO_ID"),pd.getString("CREATOR"),"YD_QT",pd.getString("CHECK_NO"),null);
            }
        }
    }

    @Override
    public void delete(PageData pd) throws Exception {
        electricityMapper.delete(pd);
    }

    @Override
    public List<PageData> list(Page page) throws Exception {
        return electricityMapper.datalistPage(page);
    }


    /*
    * 下一步
     */
    @Override
    @Transactional
    public void nextStep(PageData pd, MultipartFile[] files) throws Exception {
        PageData work = this.findById(pd);
        work.putAll(pd);
        List<String> filePaths = new ArrayList<>();
        for (int i = 0; i < files.length; i++) {
            if (files[i] != null) {
                //保存签名文件
                String ffile = DateUtil.getDays();
                String fileName = UuidUtil.get32UUID() + files[i].getOriginalFilename().substring(files[i].getOriginalFilename().lastIndexOf("."));
                smb.sshSftp(files[i], fileName, Const.FILEPATHFILE + work.getString("CORPINFO_ID") + "/" + ffile);
                filePaths.add(Const.FILEPATHFILE + work.getString("CORPINFO_ID") + "/" + ffile + "/" + fileName);
            }
        }
        PageData flow = getStep(work.get("TASK_ID"), work.get("STEP_ID"));
        work.put("STEP_ID", flow.get("NEXT_STEP_ID"));
        electricityMapper.editVideo(work);

        //保存签名信息
        PageData sign = new PageData();
        if(work.getString("IMG_PATH") != ""){
            sign.put("IMG_PATH", work.get("IMG_PATH"));
        }
        sign.put(primary_key, work.get(primary_key));
        sign.put("STEP_ID", work.get("STEP_ID"));
        sign.put("SIGN_USER_ID", work.get("USER_ID"));
        sign.put("SIGN_TIME", work.getString("SIGNTIME"));
        sign.put("SIGN_PATH", String.join(",",filePaths));
        sign.put("DESCR", work.get("DESCR"));

        electricitySignMapper.edit(sign);

        if (work.get("MEASURES") != null && !work.get("MEASURES").equals("")) { //安全措施确认步骤
            saveMeasures(work);
        }

        List<PageData> unsignedList = electricitySignMapper.checkUnsigned(sign);//当前步骤未签名人列表
        if((unsignedList == null || unsignedList.size() == 0) && pd.getString("APPLY_STATUS").equals("1")){//如果没有未签人 则跳转下一步
            electricityMapper.editStep(work);
            PageData currentflow = getStep(work.get("TASK_ID"), work.get("STEP_ID"));

            //保存日志
            saveLog(work,work.getString("USER_ID"),"1");

            //消息推送
            switch(currentflow.getString("NEXT_STEP_ID")){
                case "8":
                    sendMessageForFinishedYB(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_Y01",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "17":
                    sendMessageForFinishedYB(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_Y02",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "19":
                    sendMessageForFinishedYB(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_Y03",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "15":
                    sendMessageForFinishedYB(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_Y04",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "99":
                    eightworkvideomanagerMapper.editStatus(work);
                    sendMessageForFinishedYB(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_Y05",
                            work.getString("CHECK_NO"),null);
                    break;
                default :
                    break;
            }

            if (work.get("PREPARERS") != null && !work.get("PREPARERS").equals("")) { //如果是设置安全措施确认人步骤
                savePreparers(work,currentflow);
            }
            saveNextSigner(work,currentflow);
        }else if(pd.getString("APPLY_STATUS").equals("-1")){
            //消息推送
            switch(work.getString("STEP_ID")){
                case "8":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_N02",
                            work.getString("CHECK_NO"),work.getString("CONFIRM_USER_NAME"));
                    break;
                case "17":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_N03",
                            work.getString("CHECK_NO"),work.getString("AUDIT_USER_NAME"));
                    break;
                case "19":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_N04",
                            work.getString("CHECK_NO"),work.getString("APPROVE_USER_NAME"));
                    break;
                case "15":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"YD_N05",
                            work.getString("CHECK_NO"),work.getString("ACCEPT_USER_NAME"));
                    break;
                default :
                    break;
            }
            //保存日志
            saveLog(work,work.getString("USER_ID"),"-1");
            eightworkvideomanagerMapper.editStatus(work);
            work.put("STEP_ID",-1);
            electricityMapper.editStep(work);
        }// 作业 监护人停止
        else if ("-3".equals(pd.getString("APPLY_STATUS"))) {
            //保存日志
            saveLog(work, work.getString("USER_ID"), "-3");
            eightworkvideomanagerMapper.editStatus(work);
            work.put("STEP_ID", -3);
            electricityMapper.editStep(work);
            sendMessageForFinished(work.getString("CORPINFO_ID"), work.getString("CREATOR"), "EIGHTWORK_STOP", work.getString("CHECK_NO"), null);
        }
    }

    @Override
    public PageData findById(PageData pd) throws Exception {
        PageData pageData = electricityMapper.findById(pd);
        return pageData;
    }

    @Override
    public PageData listSignFinished(PageData pd) throws Exception {
        Map<String,List<PageData>> rmap = new HashMap<>();
        List<PageData> varList = electricitySignMapper.listAll(pd);
        if (varList != null && !varList.isEmpty()) {
            varList.stream().forEach(item -> {
                PageData sign = new PageData();
                sign.put("SIGN_PATH", item.getString("SIGN_PATH").split(","));
                sign.put("SIGN_TIME", item.getString("SIGN_TIME").split(","));
                if(item.getString("IMG_PATH") != null || "".equals(item.getString("IMG_PATH"))){
                    sign.put("IMG_PATH", item.getString("IMG_PATH").split(","));
                }
                sign.put("DESCR", item.getString("DESCR") != null ? item.getString("DESCR") : "无");
                if(rmap.containsKey(item.getString("CODE"))){
                    rmap.get(item.getString("CODE")).add(sign);
                }else{
                    List<PageData> signs = new ArrayList<>();
                    signs.add(sign);
                    rmap.put(item.getString("CODE"),signs);
                }
            });
        }
        PageData rpd = new PageData();
        if (rmap != null && !rmap.isEmpty()) {
            rpd.putAll(rmap);
        }
        return rpd;
    }

    @Override
    public PageData checkWorkCount(PageData pd) {
        PageData rpd = new PageData();
        List<PageData> varList = electricityMapper.checkWorkCount(pd);

        if (varList != null && !varList.isEmpty()) {
            Map<String, String> newMap = varList.stream()
                    .collect(Collectors.toMap(map -> map.getString("CODE"), map -> map.getString("COUNT")));

            rpd.putAll(newMap);
        }
        return rpd;
    }

    @Override
    public List<PageData> listAllMeasures() throws Exception {
        return electricityMapper.listAllMeasures();

    }

    @Override
    public List<PageData> listAllMeasuresForSign(PageData pd) throws Exception {
        return electricityToMeasuresMapper.listAllMeasuresForSign(pd);

    }

    @Override
    public List<PageData> listSignFinishMeasures(PageData pd) throws Exception {
        return electricityToMeasuresMapper.listSignFinishMeasures(pd);
    }

    @Override
    @Transactional
    public void saveGas(PageData pd, MultipartFile[] files) throws Exception {
        PageData work = electricityMapper.findById(pd);
        work.putAll(pd);
        List<String> filePaths = new ArrayList<>();
        for (int i = 0; i < files.length; i++) {
            //保存签名文件
            String ffile = DateUtil.getDays();
            String fileName = UuidUtil.get32UUID() + files[i].getOriginalFilename().substring(files[i].getOriginalFilename().lastIndexOf("."));
            smb.sshSftp(files[i], fileName, Const.FILEPATHFILE + work.getString("CORPINFO_ID") + "/" + ffile);
            filePaths.add(Const.FILEPATHFILE + work.getString("CORPINFO_ID") + "/" + ffile + "/" + fileName);
        }
        pd.put("ELECTRICITYGAS_ID", UuidUtil.get32UUID());	//主键
        pd.put("ISDELETE", "0");	//是否删除 1-是  0-否
        pd.put("SIGN_PATH",  String.join(",",filePaths));
        electricitygasMapper.save(pd);
        electricityMapper.editGasTime(pd);//修改最后一次气体检测时间

        PageData flow = getStep(work.get("TASK_ID"), work.get("STEP_ID"));
        if (pd.get("APPLY_STATUS").equals("1")) { //如果通过
            if(flow.get("NEXT_STEP_ID") != null && flow.getString("NEXT_STEP_ID").equals("2")) {//如果为气体检测步骤,则保存日志并跳转下一步
                PageData sign = new PageData();
                sign.put(primary_key, work.get(primary_key));
                sign.put("STEP_ID", 2);
                sign.put("SIGN_USER_ID", pd.get("USER_ID"));
                sign.put("SIGN_TIME", DateUtil.date2Str(new Date()));
                sign.put("SIGN_PATH", String.join(",", filePaths));
                sign.put("DESCR", pd.get("DESCR"));
                electricitySignMapper.edit(sign);
                work.put("STEP_ID", flow.get("NEXT_STEP_ID"));
                electricityMapper.editStep(work);

                //保存日志
                saveLog(work, work.getString("USER_ID"), "1");

                //预存下一步
                PageData currentflow = getStep(work.get("TASK_ID"), work.get("STEP_ID"));
                saveNextSigner(work, currentflow);
            }
        }else if(pd.getString("APPLY_STATUS").equals("-1")){
            PageData sign = new PageData();
            sign.put(primary_key, work.get(primary_key));
            sign.put("STEP_ID", 2);
            sign.put("SIGN_USER_ID", pd.get("USER_ID"));
            sign.put("SIGN_TIME", DateUtil.date2Str(new Date()));
            sign.put("SIGN_PATH", String.join(",", filePaths));
            sign.put("DESCR", pd.get("DESCR"));
            electricitySignMapper.edit(sign);
            //保存日志
            eightworkvideomanagerMapper.editStatus(work);

            work.put("STEP_ID", flow.get("NEXT_STEP_ID"));
            saveLog(work,pd.getString("USER_ID"),"-2");
            work.put("STEP_ID",-1);
            electricityMapper.editStep(work);
//            sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"EIGHTWORK_REJECT",work.getString("CHECK_NO"),null);

        }
    }

    @Override
    public List<PageData> getFlowList(PageData pd) throws Exception {
        pd=findById(pd);
        return electricityMapper.getFlowList(pd);
    }

    @Override
    public ReturnMap getMapList() throws Exception {
        ReturnMap returnMap = new ReturnMap();
        PageData pd = new PageData();
        pd.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
        returnMap.put("varList",electricityMapper.getMapList(pd));
        return returnMap;
    }

    @Override
    public void updateSpecial(String specialWork,String table,String primaryKey) throws Exception {
        PageData pd = new PageData();
        pd.put("SPECIAL_WORK",specialWork);
        pd.put("table",table);
        pd.put("primaryKey",primaryKey);
        List<PageData> list = electricityMapper.getSpecial(pd);
        for (PageData pageData: list) {
            if (Tools.notEmpty(pageData.getString("SPECIAL_WORK"))) {
                String[] specialWorks = pageData.getString("SPECIAL_WORK").split(",");
                String[] newArr = removeElement(specialWorks, "无");
                String[] newString = removeElement(newArr, specialWork);
                StringBuffer newSpecialWork = new StringBuffer();
                if(newString.length > 0){
                    newSpecialWork.append(String.join(",",newString));
                }
                pageData.put("SPECIAL_WORK",newSpecialWork.toString());
                pageData.put("table",table);
                pageData.put("primaryKey",primaryKey);
                pageData.put("primaryKeyVlu",pageData.get(primaryKey));
                electricityMapper.updateSpecial(pageData);
            }
        }
    }

    public static String[] removeElement(String[] arr, String valueToDelete) {
        int newSize = 0;
        for (String element : arr) {
            if (!element.equals(valueToDelete)) {
                newSize++;
            }
        }

        String[] newArr = new String[newSize];
        int index = 0;
        for (String element : arr) {
            if (!element.equals(valueToDelete)) {
                newArr[index++] = element;
            }
        }
        return newArr;
    }

    private void saveNextSigner(PageData pd,PageData flow) throws Exception {

        pd.put("STEP_ID",flow.get("NEXT_STEP_ID"));

        if(pd.get(flow.get("NEXT_ACTOR_FIELD")) == null || pd.get(flow.get("NEXT_ACTOR_FIELD")).equals("")){
            return;
        }
        //提前保存下一步签字人
        List<PageData> signers  = new ArrayList<>();
        PageData signer = new PageData();
        signer.put("ELECTRICITY_SIGN_ID", UuidUtil.get32UUID()); // 主键
        signer.put(primary_key, pd.get(primary_key));
        signer.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
        signer.put("SIGN_USER_ID", pd.get(flow.get("NEXT_ACTOR_FIELD")));
        signer.put("STEP_ID", flow.get("NEXT_STEP_ID"));
        signers.add(signer);
        electricitySignMapper.saveBatch(signers);
//        sendMessageForNext(pd.getString("CORPINFO_ID"),pd.getString(flow.get("NEXT_ACTOR_FIELD")),pd.getString("CHECK_NO"),flow.getString("NEXT_STEP_NAME"));

    }

    private void saveMeasures(PageData pd) {
        List<JSONObject> list = (List<JSONObject>) JSON.parse(pd.get("MEASURES").toString());
        for (JSONObject json : list) {
            PageData measure = new PageData();
            measure.put("ELECTRICITYTOMEASURES_ID",json.get("ELECTRICITYTOMEASURES_ID"));
            measure.put("STATUS", json.get("STATUS"));
            measure.put("ANSWER1", json.get("ANSWER1"));
            measure.put("ANSWER2", json.get("ANSWER2"));
            measure.put("ANSWER3", json.get("ANSWER3"));
            measure.put("SIGN_PATH", json.get("SIGN_PATH"));
            measure.put("SIGN_TIME", json.get("SIGN_TIME"));
            measure.put("IMG_PATH", json.get("IMG_PATH"));
            electricityToMeasuresMapper.edit(measure);
        }
    }

    private void savePreparers(PageData pd,PageData flow) {
        List<PageData> signers = new ArrayList<>();
        List<JSONObject> list = (List<JSONObject>) JSON.parse(pd.get("PREPARERS").toString());
        for (JSONObject json : list) {
            PageData preparer = new PageData();
            preparer.put("ELECTRICITYTOMEASURES_ID", UuidUtil.get32UUID()); // 主键
            preparer.put("ELECTRICITY_ID", pd.get("ELECTRICITY_ID"));
            preparer.put("BUS_ELECTRICITY_MEASURES_ID", json.get("BUS_ELECTRICITY_MEASURES_ID"));
            preparer.put("CONFIRM_ID", json.get("USER_ID"));
            signers.add(preparer);
        }
        if(signers.size() > 0){
            electricityToMeasuresMapper.saveBatch(signers);

            //获取所有需要签名人
            List<String> fieldList = signers.stream()
                    .map(map -> map.getString("CONFIRM_ID"))
                    .collect(Collectors.toList());
            Set<String > fieldSet = new HashSet<>(fieldList); //去重

            List<String> uniqueList = new ArrayList<>(fieldSet);
            List<PageData> nextSigners  = new ArrayList<>();
            uniqueList.forEach(item -> { // 保存下一步需要签名的人
                PageData signer = new PageData();
                signer.put("ELECTRICITY_SIGN_ID", UuidUtil.get32UUID()); // 主键
                signer.put(primary_key, pd.get(primary_key));
                signer.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
                signer.put("SIGN_USER_ID", item);
                signer.put("STEP_ID", flow.get("NEXT_STEP_ID"));
                nextSigners.add(signer);

//                try {
//                    sendMessageForNext(pd.getString("CORPINFO_ID"),item,pd.getString("CHECK_NO"),flow.getString("NEXT_STEP_NAME"));
//                } catch (Exception e) {
//                    throw new RuntimeException(e);
//                }
            });

            electricitySignMapper.saveBatch(nextSigners);
        }
    }

    private PageData getStep(Object TASK_ID, Object STEP_ID) throws Exception {
        PageData flow = new PageData();
        flow.put("TASK_ID", TASK_ID);
        flow.put("STEP_ID", STEP_ID);
        flow = eightWorkTaskFlowMapper.getStep(flow);
        return flow;
    }

    private void saveLog(PageData pd,String act_user,String status) throws Exception {

        PageData log = new PageData();
        log.put("LOG_ID", UuidUtil.get32UUID());
        log.put("WORK_ID", pd.get(primary_key));
        log.put("TASK_ID", pd.get("TASK_ID"));
        log.put("STEP_ID", pd.get("STEP_ID"));
        log.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
        log.put("CHECK_NO", pd.get("CHECK_NO"));
        log.put("ACT_USER", act_user);
        log.put("ACT_TIME", DateUtil.date2Str(new Date()));
        log.put("STATUS", status);
        log.put("WORK_TYPE",work_type);
        eightWorkFlowLogMapper.save(log);

    }
    private PageData getCurrentFlow(PageData pd) throws Exception {
        PageData flow = new PageData();
        flow.put("TASK_ID", pd.get("TASK_ID"));
        flow.put("STEP_ID", pd.get("STEP_ID"));
        flow = eightWorkTaskFlowMapper.getStep(flow);
        if("1".equals(flow.getString("CAN_SKIP")) && (pd.get(flow.get("NEXT_ACTOR_FIELD")) == null || pd.get(flow.get("NEXT_ACTOR_FIELD")).equals(""))){
            pd.put("STEP_ID", flow.get("NEXT_STEP_ID"));
            return getCurrentFlow(pd);
        }else{
            return flow;
        }
    }

    private void setPosition(PageData pd) throws Exception {
        JSONObject body = PLSUtil.getRyRegionInfo(pd.getString("CORPINFO_ID"),Integer.parseInt(pd.getString("PLS_ID")));
        List pointList = (List)((Map) body.get("data")).get("list");
        List<String> positions = PLSUtil.getRandomPointInPolygon(pointList);
        pd.put("WORK_POSITION", String.join(",",positions));
        electricityMapper.setPosition(pd);
    }
    private void sendMessageForNext(String corpinfo_id,String userId,String number,String flow_name) throws Exception {
        PageData mes = new PageData();
        mes.put("RECEIVER_ID", userId);// 收信人userid
        mes.put("templateCode", "EIGHTWORK_REMINDER");// 短信模板编码
        mes.put("CORPINFO_ID", corpinfo_id);// 企业id

        // 参数集合
        List<PageData> paramsList = new ArrayList<PageData>();
        // 第1个参数
        PageData params1 = new PageData();
        params1.put("name", "number");// 存入短信模板中的参数名称
        params1.put("value", number);// 存入上面参数名称所传递的值
        paramsList.add(params1);

        PageData params2 = new PageData();
        params2.put("name", "type");// 存入短信模板中的参数名称
        params2.put("value", "临时用电作业");// 存入上面参数名称所传递的值
        paramsList.add(params2);

        PageData params3 = new PageData();
        params3.put("name", "flow");// 存入短信模板中的参数名称
        params3.put("value", flow_name);// 存入上面参数名称所传递的值
        paramsList.add(params3);
        try {
            sendMessageUtil.sendMessages(mes, paramsList);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private void sendMessageForFinishedYB(String corpinfo_id,String userId,String template,String number,String stepName) throws Exception {
        PageData mes = new PageData();
        mes.put("RECEIVER_ID", userId);// 收信人userid
        mes.put("templateCode", template);// 短信模板编码
        mes.put("CORPINFO_ID", corpinfo_id);// 企业id

        // 参数集合
        List<PageData> paramsList = new ArrayList<PageData>();
        if("YD_Y05".equals(template)){
            // 第1个参数
            PageData params = new PageData();
            params.put("name", "number");// 存入短信模板中的参数名称
            params.put("value", number);// 存入上面参数名称所传递的值
            paramsList.add(params);

            PageData params1 = new PageData();
            params1.put("name", "type");// 存入短信模板中的参数名称
            params1.put("value", "临时用电作业");// 存入上面参数名称所传递的值
            paramsList.add(params1);
        }else{
            // 第1个参数
            PageData params = new PageData();
            params.put("name", "number");// 存入短信模板中的参数名称
            params.put("value", number);// 存入上面参数名称所传递的值
            paramsList.add(params);

            PageData params1 = new PageData();
            params1.put("name", "params1");// 存入短信模板中的参数名称
            params1.put("value", "临时用电作业");// 存入上面参数名称所传递的值
            paramsList.add(params1);

            PageData params2 = new PageData();
            params2.put("name", "params2");// 存入短信模板中的参数名称
            params2.put("value", stepName);// 存入上面参数名称所传递的值
            paramsList.add(params2);

            PageData params3 = new PageData();
            params3.put("name", "params3");// 存入短信模板中的参数名称
            params3.put("value", "确认审批");// 存入上面参数名称所传递的值
            paramsList.add(params3);
        }
        try {
            sendMessageUtil.sendMessages(mes, paramsList);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private void sendMessageForFinished(String corpinfo_id,String userId,String template,String number,String stepName) throws Exception {
        PageData mes = new PageData();
        mes.put("RECEIVER_ID", userId);// 收信人userid
        mes.put("templateCode", template);// 短信模板编码
        mes.put("CORPINFO_ID", corpinfo_id);// 企业id

        // 参数集合
        List<PageData> paramsList = new ArrayList<PageData>();
        // 第1个参数
        PageData params = new PageData();
        params.put("name", "params1");// 存入短信模板中的参数名称
        params.put("value", number);// 存入上面参数名称所传递的值
        paramsList.add(params);

        PageData params1 = new PageData();
        params1.put("name", "params2");// 存入短信模板中的参数名称
        params1.put("value", "临时用电作业");// 存入上面参数名称所传递的值
        paramsList.add(params1);

        if(!"YD_QT".equals(template)){
            PageData params2 = new PageData();
            params2.put("name", "params3");// 存入短信模板中的参数名称
            params2.put("value", stepName);// 存入上面参数名称所传递的值
            paramsList.add(params2);
        }


        try {
            sendMessageUtil.sendMessages(mes, paramsList);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
